/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_CHAFFVERB_HPP_
#define _HEAVY_CONTEXT_CHAFFVERB_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvTable.h"
#include "HvSignalTabread.h"
#include "HvControlPack.h"
#include "HvMath.h"
#include "HvControlCast.h"
#include "HvSignalLine.h"
#include "HvControlSystem.h"
#include "HvSignalTabwrite.h"
#include "HvControlIf.h"
#include "HvSignalPhasor.h"
#include "HvSignalRPole.h"
#include "HvControlTabhead.h"
#include "HvControlBinop.h"
#include "HvControlRandom.h"
#include "HvSignalDel1.h"
#include "HvControlSlice.h"
#include "HvControlVar.h"
#include "HvControlUnop.h"
#include "HvSignalVar.h"
#include "HvControlDelay.h"

class Heavy_ChaffVerb : public HeavyContext {

 public:
  Heavy_ChaffVerb(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_ChaffVerb();

  const char *getName() override { return "ChaffVerb"; }
  int getNumInputChannels() override { return 1; }
  int getNumOutputChannels() override { return 2; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        A__LFO_PERIOD = 0x1F30993F, // A__LFO_Period
        A__LFO_STEPS_SCALE__TYPE2 = 0x1A2B8E9F, // A__LFO_Steps_Scale__Type2
        A__LFO_STEPS__TYPE2 = 0xBE3344C8, // A__LFO_Steps__Type2
        A__LFO_SWITCH = 0x7369936E, // A__LFO_Switch
        A__LFO_TYPE = 0xD64CFD23, // A__LFO_type
        B__GENERAL_OFFSET = 0x51447E19, // B__General_Offset
        B__GENERAL_SCALE = 0xA10FCFC4, // B__General_Scale
        C__RANDOM_LFO_OFFSET = 0x7EFB8E46, // C__Random_LFO_Offset
        C__RANDOM_LFO_PERIOD = 0xE6223016, // C__Random_LFO_Period
        C__RANDOM_LFO_SCALE = 0x3281900D, // C__Random_LFO_Scale
        C__RANDOM_LFO_SWITCH = 0x6150BC53, // C__Random_LFO_Switch
        D__SHIFT_MICROTONE = 0x9CBB1BF3, // D__Shift_Microtone
        D__SHIFT_TRANSPOSE = 0x4439D71, // D__Shift_Transpose
        E__FX_LEVEL = 0x890283C2, // E__Fx_Level
        E__HIPASS_FREQ = 0x12962685, // E__HiPass_Freq
        E__SHIFT_DELAY = 0x183CFEE5, // E__Shift_Delay
        E__SHIFT_WINDOW = 0x57FF40DB, // E__Shift_Window
        F__FX_DELAY = 0x69A91334, // F__FX_Delay
        F__FX_DELAY_FEEDBACK = 0x68D029F7, // F__FX_Delay_Feedback
        MIX__DRY_MIX = 0xD63693D0, // Mix__Dry_Mix
        MIX__DRY_VOL = 0x1FC3C02C, // Mix__Dry_Vol
        MIX__REVERB_LEVEL = 0x58653D84, // Mix__Reverb_Level
        MIX__REVERB_VOL = 0xE764F673, // Mix__Reverb_Vol
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void cVar_kTHyhiYy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_vRXYPTzD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_E9OvjDK4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_IV0omvj8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zU6UZf5K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_gtpSyf3M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_7LjCRhx2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Ioq1yAOj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_PHxxbvLS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Y46mOHFG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_fzv1Yl3O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_O65UfwkA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_VcLRwIah_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_P4Yuyhcj_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_eu459mF1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_XQCKfQ7C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GMYLoeOC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WeoEFzc7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IyL3cMF2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_eHLsNxXe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_odJCZim8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0F7RFBDi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jNee8IXR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_7BDOuLpY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_gVigWLva_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_NtBtT15u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BOBmKPLH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vMMdyqPx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Zd0YEuzd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QTZvosFJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_AFOnokSZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_gN1ufwuj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_ytRMkczW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_b46K0o3p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gV2tVuJB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_65aDF6Ko_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1p1qWNCX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XySsshbo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_sLq86R90_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_IkKvg41s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PqS42mNX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LFuFZnjz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MMuVIpcN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CxI6axwB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_L7PwWTLk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_rrlKy3jZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_c15KAOQs_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_sRsnxOwC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_4ytw6kOR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_c1U6NqAp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XonMbqI4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4b9mBZ9S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_vMM3bEiQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_F8HtLmXE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_gY2nUprh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Q0I0k36I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WxhuPKLg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yC7F09W0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OwNHd610_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Itw6bo8C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bUIEEGZi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JpXaKS9z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NwHadRgV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_djRIBQzX_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_F7c8q80i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_VeYiluKZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cRandom_wivvdnhO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_fl9bGCII_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_aQukJHnF_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_VVKa8ii8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_oZLLZneR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yLnEQeGy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_QrVWT3KK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_nknlzmzF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2yH11CP3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TOoj19kX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mMt7NDmO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mq3muuyI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_7rF397Ln_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BbvRIzj2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_Dq4Fxu8k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_P7D9lUQL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_sON2ACiY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_bIag6k5E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_32892OHy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_i87XpHOk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Rcncf8Ya_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NUHmjaw3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_zK6UDMNe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1OjX8Q5j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xmzERKTU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kdT6nrmn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wMaXloOH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_o3JRgC00_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_F5Rz4Uhn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2ZD99GJC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ZUsrwxoA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_VA4Dpeln_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_N4z46cdl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_XOS5kXk3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_duAmrU2D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_BeLuy1it_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_FLt63fKl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_th3G4Otl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WXw8IIYR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZxQ9lK3d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xmjksoHB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_Xlu6fqKp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JJr6wQEc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DWk1wEMg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mDQE0neO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qSb7oLea_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xcXWCvPO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DJ7SZ9l0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_upqOD3jx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_n3kNHbC2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_XqHlMAIZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Jc3YVD6l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_MpHgxg5N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_UQx5Ua7V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_AQVZZgml_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_aAaNTnw9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_AE4mA9Hx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_90swmuyA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WdQdK43f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IVsbH4SK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_pRpBW1tG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ghdo8ENq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_noBAFEzh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_309yVvD4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3IH8BjUv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9lXmPfhl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9IQyeoLr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5XBWd3sJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ATQZ2mft_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_UAq06X24_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4BG8WR8j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_oRl8L6JU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_8J0IaKxO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_SMvEgPUF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_KPxlbWXO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_X6xTsZnq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XT5uGTEk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9ZeZi6JC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_StfOboQf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_A7I64GsP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_VIlb0SWI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_D6Wrei83_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3QmcAzeL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MP4FfcKz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_vTnFUhfO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_F9JJxI3T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_x9fnkLkb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_oeSsWBTt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6kPqJ1hx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_uQsSKHr1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_4kORenPA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_ytjFawbk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_AXOUftUU_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_1CZnNarz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_7kBrnt8n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5OzUP8C3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QnxkvObL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tqTlZJw8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Z9muUZ3c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DLTply1b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SaB8uGuB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_sKm1mgSw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_D7G7X6pT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_C4wXfBeJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_Xlv7V6aR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_HpW0hPN8_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_wbptSjuN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_1xUNdlcx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_a9KDEaYj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6vGREai6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JBcSLajx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_PVJjUAS1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_aloHAn46_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SlGBNbB9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Gl43MpP2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_lrfC8gu4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_hhAVud4i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_OJotLSZG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_RCgoxEuJ_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_C3Fa0nna_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_nm3JUNrt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Nhbrn1Ie_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_p4yT5hXz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HTVB73gb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HhOE115Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wVGj9gWN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cD6eiIWZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ArNEA6sz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_tNofymvL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_NepzIRVJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_PGkuQft8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_xqz1wywP_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_vtBf2eop_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_rsPSl4Tm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6vRfkiLy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_doanKiCB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ywCNvpql_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xrvixtiR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_aGqYcOb9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qsGH07Gs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_wNA7kvlC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_JBiKGciB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9VaCmh0x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kASqpcXb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_7ggzn5Xa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_pZycvGpy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_WziA1f6m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_K7l76Jf2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nQLueF4y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_i7oSQtEE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_T4FeJFuM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_y8xS2Sxd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mCi6LIx7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_GeRuZH7Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_c6zEK3um_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_mwrwjSDQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_rEr8UQZ4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_PcnMCFSg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bWK8nizr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kjQi6ijo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jRtoRJ1f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7ThxcDek_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_hIB7FzNR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_ahxUkapM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_sye1z9Wd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_I3twc1nT_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_OEahZ9AP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_vXtBaWoj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_A1eCcjBN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KBeSI2L8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nsW5ew2c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GkN1GdSo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CBOuE36E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vaUUCDwG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_x2nIKaC8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_P1dpeHgH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_EJyTaO5s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_jJcbCOKM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_ZS0nhyOr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_lkFsyYNC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_XTMScFCN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pICtUoFf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UgbVPzbD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PjHLNWo3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_JREmjov9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HxYalM7K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_VU2lIrUm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_TPV2IYLr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_y4dljvy2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_W6qoaHMd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vJNiDuZI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_m2uQ3ZU7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_bJkKG9XV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_pcGEEDB2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_JIUT4wvl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_A22Y5jMS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_XVwWty9X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_aZsY2cQ6_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_TyeqGB07_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_uE3Ot1l8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_oX5E1uR1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZflEpHtB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_34C9l6jh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_sIuQc7yM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9URvEttJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Zm1X8unb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_6Vy8nZVe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wHRToKRL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_4EIpLCeq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Mf7QKgUx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_KAvz7USG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_3VaqIJDR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_M0VW0xTw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YNxW4vml_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jGV7Kqw1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_aja27uYt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_sCV1wmNg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_sHVYFihx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_q7jwYmZV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wGVAWwuB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oX2lntrp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9PuVTALd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_brcAl4oy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nDfllkRe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_V8Cd1Dsd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_N6jr4Ckb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_nQscFIOo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_j4ukQrjq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_fNgTCjFU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_0sWt2Fyu_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_LiZWSINr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_DrAvi7Sc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mIxLuNMg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OXHGQKTG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9um9bxSH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HevBg66p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DIj5nGMl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_V8kUgIrs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_zyHrbWra_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CB0huZq9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_MG6nhfMI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_bgjx0mgk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_UIj6a4jk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_ZbOa7VDi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_eJqQW8jk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vwkI5CYg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kWDrr42H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_b8fugLPa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_DxnHERYb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zgcvKPkH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_71cZPPjV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8PaZS3po_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QYzZGBBV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_htomWwgW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0csjVuHV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_roQ4Qwio_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_C0Mm96OB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MBwZye4N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_IWx0kb68_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_Px84b0no_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_9tjciN2j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_5yDLaby5_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_OimAC3rd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_2WS3L7y9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1zrkWvWK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rmgAIBEl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ivGpXkV5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_i9thlQ5V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lbStRgtE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UqSQaLGU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_20BNRcIp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Eb64wrwn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_NaGw7Mqc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_zzQBv86M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_vCv9eIP6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_bP9ZfhRf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_roh7vvPE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SnEBMlYc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_udXl7t7m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4i9pubG8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_FIh8FRZM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NnUuwxEW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_iCLp5daO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fcKyUGis_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tqxpDGic_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_jFFPQND0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fdFTHIZy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_llnytlO3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1hdpcnRv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9WYVuL60_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_A5iejV6I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_fflkwnoD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_nRjebdX3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_JEUll63z_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_dsQPZ6o2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_j7wVbqKq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fN3PIY3j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4WvVU3D5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xYXlP7HP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_elhKUarA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XG7c11j4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DAwCzZvd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_ojFAOURY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_YpElZbo7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_3qzw2uWn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ESqy9KLJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_ISDAUf0Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_qoy4b32I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_UI1hGaCm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bzMlKF7P_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_s1lLdTT6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XojDhFOY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_b9jU9jtw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_e5noVJUi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2LXh3dJH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_A96hIF3Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FnOPDHcS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zj4ZaxVh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KPLMlns5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_k7oNpgJL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ewG2OqBM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZN9jokWa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_imUxIHVX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_MYe6A5UG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_Cdv7eGzd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_swWgxSCw_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_9Ws7xr6D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_R3bW1ryO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HSce5Fne_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NbkVlCZ0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_elfAolBq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ZHu0WLae_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Gd1RaJvQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_uKpVpDwv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_3Z4GP1lw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_s43d9apf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_0GMwlXDR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_1GhhzQiX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_H8Gx4Ne0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_Kc2Mgbkx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_myNO78PS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VBiHMfQ2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_j7F6pcSZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sg5CTzNp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_oPb86mey_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Xuhrtue7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ehW6tAKD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_a3nVOI5C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OPvv6QhH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_RgIXwwCv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1TmAYPJ9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KOyAKbne_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_IaETr6lG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_XToIk3cI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_xH7yhFLM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_nPkX560h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_870tR97r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qE3KV6sc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_4CE8e95y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_v4aIcEEu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qm9mdiGV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wtLtnUWo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1uNJKNyN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NxWgp1RW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_eW8H9Y2U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_36Hdjr4O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IKFJzVKb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_13K29m74_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5bqI1w0a_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tJq7hsqs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dDm1JzlE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rJPiPzuc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zCwgdrpO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dEdQvdbt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_VzFTSVBr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ekrpEKbM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_r12xyFDw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Joq4HPhn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_COwCNYtw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_S4Wv85xM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UmyZoolH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4bv02oBp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PixbKoF5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uB68DMSz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UTNVBYnF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gdkvByGa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_G3XpwHNJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_JHIKzsBm_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_FniIefJj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_OkqvprUU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_arFlRXFW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_EovWbvAP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_HEIBQLRE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vmHuSlu3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Qrtx3T7c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bCa55Dgs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_M7oZQur3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_wv8dTcxM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_lCuSMW0x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_KJHqhoHn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_fxY7NK9u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_9V1V6Fp4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DSD6xFVT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Wfs7qNLk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_6WZStDUG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_PsJaucOg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_abrmloQ2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_s3zLF1an_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_38Dq8IKh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_qPv6SYuZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zd2Om2s5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GUVMPm6m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XIB0Y6Ny_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_P2verSBN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_q9Igubmu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_RgpLXTE8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_Qd19PyIl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CtlClCf9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_OsDsDrq3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_qLNXrpCm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_S0KJbk0R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_djPkvxid_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_P8ehkYPp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BhHweMHL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ipNUcMi8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Svo2ojuC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_7w49Bt1l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IPTbz8Su_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xPOW3ELI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_98XaneWX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jCMoAAiZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_IsmDKisa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6iD7Ntn5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3H9BCyXn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_kV718FFK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_aGuwUUvD_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_TG5jYFgP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_zceXu0z1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_ctLBx4Z6_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_H1TRBzEA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_wwjyLONC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_1kM9Lyjj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_8eA3mzTq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_f5s8lD5r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_EhZoxPnC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_Q9KDbpTf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_We7pMSpN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_uKUdecVW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tKpKF4cO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_fohi0EP4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_jtPQX25A_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_OkeDeAni_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_a5DhQn8d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XhP4OtiB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_Fph5q7I8_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_h8wN5t0q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_raZiFjZB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_qBHkjBEJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_E51ZYIw9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_gyiZde7a_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Fr7xs5Cl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DU8eV5KV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GMSOOr7Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_O1ZNdDbZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_dUeJW8P0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_8Gs21bY2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_E6quI8sN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_EoviPapw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_PCRtKCLF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2nnMsq0K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wBFSo0Gv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yU9uGtZO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_sgNgPOyl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4YUXW1Ft_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pooyA0ml_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8KQ1A6ig_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gTgtg2x7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JoeXyhuP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Q8wZh0Bb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BAQEzUDV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wYd4cp7n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HQ96rqae_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_CTp6ftGN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_IHJi8dlS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_We6lvphv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CGasukQS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wFuVYI6y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jcf94T5Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PTQVqXil_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0qR8tXAg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nOFPGKqD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DRPxU21g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uEthG7RL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WEkHzUpG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XoLqzPA5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1xSf6IJV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_imJ3hHTn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Ebl1qs5H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Cp4Ni6Wb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_bWaylPCT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LnXw77U9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_7X5Coj8S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zvljxCMo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_BCIeFYZI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1GeZCDsV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_r784Q2R5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_txVUfyjq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_U5HEgj1P_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XfPGrSpB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Q96JIfcf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_E3yvupMM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_BugljAKE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_RmXxLj9r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_qcMciCFH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dxnOvtov_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_WHp89IcV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_LagiHFgr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_7uzdluK5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Pj7QEql7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_PO6ifWxZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_9abq3WiE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_9itnJKNa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_w3eOFv0L_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_j6ciMmg6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_CLixaqgH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_z6tYpPbN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_c7kesexW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_sC0lFmd6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_KKh5G0Rb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Md9Z4CsW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_j1eSrFq1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_A1LPCwC8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_FZeOcAZs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_kDKz0ruv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_gQXAcfx6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_jHrKk7A3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_DHhSlRP0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_YCcSeHsB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_wcthEm55_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalPhasor sPhasor_jqFAl0mu;
  SignalLine sLine_adXc1aZq;
  SignalLine sLine_w4AE0Pc3;
  SignalTabhead sTabhead_llE3uGZ9;
  SignalTabread sTabread_BxOq9RFd;
  SignalTabread sTabread_1icfGVw7;
  SignalTabhead sTabhead_eSiD4ph9;
  SignalTabread sTabread_VgKBW2M2;
  SignalTabread sTabread_cBTnkZnp;
  SignalTabwrite sTabwrite_tSJrGowR;
  SignalRPole sRPole_9rrRq1bE;
  SignalDel1 sDel1_WutqWsYf;
  SignalTabread sTabread_P8ehkYPp;
  SignalTabwrite sTabwrite_DcSXWpAy;
  SignalTabread sTabread_32892OHy;
  SignalRPole sRPole_SINHaRIo;
  SignalLine sLine_RHG7goVo;
  SignalLine sLine_ynbCPTOR;
  SignalTabread sTabread_XTMScFCN;
  SignalTabread sTabread_M0VW0xTw;
  SignalTabread sTabread_eJqQW8jk;
  SignalTabread sTabread_roh7vvPE;
  SignalTabread sTabread_myNO78PS;
  SignalTabread sTabread_UI1hGaCm;
  SignalTabwrite sTabwrite_SBUXmKRO;
  SignalTabwrite sTabwrite_WbBLYnnu;
  SignalTabwrite sTabwrite_GWSzT4Ha;
  SignalTabwrite sTabwrite_F6KBU0Qs;
  SignalTabwrite sTabwrite_OR6AOtRm;
  SignalTabwrite sTabwrite_jDiXJTXV;
  SignalTabread sTabread_th3G4Otl;
  SignalRPole sRPole_szYy3G4Y;
  SignalTabread sTabread_AE4mA9Hx;
  SignalRPole sRPole_YJJdJTRL;
  SignalTabread sTabread_X6xTsZnq;
  SignalRPole sRPole_yQ0RDj9k;
  SignalTabwrite sTabwrite_MMvhf21d;
  SignalTabwrite sTabwrite_YERfVzFy;
  SignalTabwrite sTabwrite_O51OxZpp;
  SignalTabwrite sTabwrite_Lw4JCPC8;
  SignalLine sLine_J29RWejQ;
  ControlVar cVar_kTHyhiYy;
  ControlVar cVar_vRXYPTzD;
  ControlPack cPack_E9OvjDK4;
  ControlBinop cBinop_zU6UZf5K;
  ControlVar cVar_gtpSyf3M;
  ControlPack cPack_7LjCRhx2;
  ControlVar cVar_Ioq1yAOj;
  ControlVar cVar_PHxxbvLS;
  ControlDelay cDelay_O65UfwkA;
  ControlDelay cDelay_VcLRwIah;
  ControlBinop cBinop_eu459mF1;
  HvTable hTable_XQCKfQ7C;
  ControlBinop cBinop_WeoEFzc7;
  ControlVar cVar_gVigWLva;
  ControlBinop cBinop_BOBmKPLH;
  ControlBinop cBinop_Zd0YEuzd;
  SignalVarf sVarf_kyYyuJYL;
  SignalVarf sVarf_7exNcQqJ;
  SignalVarf sVarf_SXxXcnZP;
  ControlVar cVar_gN1ufwuj;
  ControlBinop cBinop_b46K0o3p;
  ControlBinop cBinop_65aDF6Ko;
  SignalVarf sVarf_wyF0t4Nh;
  SignalVarf sVarf_7HLaK9Ca;
  SignalVarf sVarf_ibCuJfoF;
  ControlBinop cBinop_1p1qWNCX;
  ControlBinop cBinop_XySsshbo;
  ControlBinop cBinop_PqS42mNX;
  ControlBinop cBinop_LFuFZnjz;
  ControlBinop cBinop_MMuVIpcN;
  ControlBinop cBinop_CxI6axwB;
  ControlBinop cBinop_L7PwWTLk;
  ControlBinop cBinop_XonMbqI4;
  ControlBinop cBinop_4b9mBZ9S;
  SignalVarf sVarf_3z5ORaK8;
  ControlVar cVar_vMM3bEiQ;
  ControlBinop cBinop_Q0I0k36I;
  ControlBinop cBinop_WxhuPKLg;
  ControlBinop cBinop_OwNHd610;
  ControlBinop cBinop_Itw6bo8C;
  ControlBinop cBinop_bUIEEGZi;
  ControlBinop cBinop_JpXaKS9z;
  ControlBinop cBinop_NwHadRgV;
  SignalVarf sVarf_DtIkXdBW;
  ControlBinop cBinop_F7c8q80i;
  ControlRandom cRandom_wivvdnhO;
  ControlSlice cSlice_fl9bGCII;
  ControlDelay cDelay_VVKa8ii8;
  ControlVar cVar_nknlzmzF;
  ControlBinop cBinop_TOoj19kX;
  ControlBinop cBinop_mMt7NDmO;
  ControlBinop cBinop_mq3muuyI;
  ControlTabhead cTabhead_7rF397Ln;
  ControlVar cVar_P7D9lUQL;
  ControlDelay cDelay_sON2ACiY;
  ControlDelay cDelay_bIag6k5E;
  ControlBinop cBinop_i87XpHOk;
  ControlBinop cBinop_Rcncf8Ya;
  ControlBinop cBinop_NUHmjaw3;
  ControlBinop cBinop_wMaXloOH;
  ControlBinop cBinop_F5Rz4Uhn;
  ControlBinop cBinop_2ZD99GJC;
  ControlTabhead cTabhead_VA4Dpeln;
  ControlVar cVar_duAmrU2D;
  ControlDelay cDelay_BeLuy1it;
  ControlDelay cDelay_FLt63fKl;
  ControlBinop cBinop_WXw8IIYR;
  ControlBinop cBinop_ZxQ9lK3d;
  ControlBinop cBinop_xmjksoHB;
  ControlBinop cBinop_qSb7oLea;
  ControlBinop cBinop_DJ7SZ9l0;
  ControlBinop cBinop_upqOD3jx;
  ControlTabhead cTabhead_XqHlMAIZ;
  ControlVar cVar_UQx5Ua7V;
  ControlDelay cDelay_AQVZZgml;
  ControlDelay cDelay_aAaNTnw9;
  ControlBinop cBinop_90swmuyA;
  ControlBinop cBinop_WdQdK43f;
  ControlBinop cBinop_IVsbH4SK;
  ControlBinop cBinop_3IH8BjUv;
  ControlBinop cBinop_9IQyeoLr;
  ControlBinop cBinop_5XBWd3sJ;
  ControlTabhead cTabhead_UAq06X24;
  ControlVar cVar_8J0IaKxO;
  ControlDelay cDelay_SMvEgPUF;
  ControlDelay cDelay_KPxlbWXO;
  ControlBinop cBinop_XT5uGTEk;
  ControlBinop cBinop_9ZeZi6JC;
  ControlBinop cBinop_StfOboQf;
  ControlBinop cBinop_MP4FfcKz;
  ControlBinop cBinop_F9JJxI3T;
  ControlBinop cBinop_x9fnkLkb;
  ControlDelay cDelay_4kORenPA;
  ControlDelay cDelay_ytjFawbk;
  ControlBinop cBinop_1CZnNarz;
  HvTable hTable_7kBrnt8n;
  ControlBinop cBinop_QnxkvObL;
  ControlDelay cDelay_C4wXfBeJ;
  ControlDelay cDelay_Xlv7V6aR;
  ControlBinop cBinop_wbptSjuN;
  HvTable hTable_1xUNdlcx;
  ControlBinop cBinop_6vGREai6;
  ControlDelay cDelay_hhAVud4i;
  ControlDelay cDelay_OJotLSZG;
  ControlBinop cBinop_C3Fa0nna;
  HvTable hTable_nm3JUNrt;
  ControlBinop cBinop_p4yT5hXz;
  ControlDelay cDelay_NepzIRVJ;
  ControlDelay cDelay_PGkuQft8;
  ControlBinop cBinop_vtBf2eop;
  HvTable hTable_rsPSl4Tm;
  ControlBinop cBinop_doanKiCB;
  ControlPack cPack_wNA7kvlC;
  ControlPack cPack_JBiKGciB;
  ControlBinop cBinop_9VaCmh0x;
  ControlBinop cBinop_kASqpcXb;
  ControlVar cVar_7ggzn5Xa;
  ControlBinop cBinop_K7l76Jf2;
  ControlBinop cBinop_nQLueF4y;
  SignalVarf sVarf_CERnyAlN;
  ControlBinop cBinop_T4FeJFuM;
  ControlBinop cBinop_y8xS2Sxd;
  ControlBinop cBinop_mCi6LIx7;
  SignalVarf sVarf_LkrWIftb;
  ControlVar cVar_GeRuZH7Z;
  ControlVar cVar_c6zEK3um;
  ControlVar cVar_mwrwjSDQ;
  ControlVar cVar_rEr8UQZ4;
  ControlIf cIf_PcnMCFSg;
  ControlBinop cBinop_bWK8nizr;
  ControlBinop cBinop_kjQi6ijo;
  ControlBinop cBinop_jRtoRJ1f;
  ControlDelay cDelay_ahxUkapM;
  ControlDelay cDelay_sye1z9Wd;
  ControlBinop cBinop_OEahZ9AP;
  HvTable hTable_vXtBaWoj;
  ControlBinop cBinop_KBeSI2L8;
  ControlTabhead cTabhead_x2nIKaC8;
  ControlVar cVar_jJcbCOKM;
  ControlDelay cDelay_ZS0nhyOr;
  ControlDelay cDelay_lkFsyYNC;
  ControlBinop cBinop_pICtUoFf;
  ControlBinop cBinop_UgbVPzbD;
  ControlBinop cBinop_PjHLNWo3;
  ControlBinop cBinop_y4dljvy2;
  ControlBinop cBinop_vJNiDuZI;
  ControlBinop cBinop_m2uQ3ZU7;
  ControlDelay cDelay_A22Y5jMS;
  ControlDelay cDelay_XVwWty9X;
  ControlBinop cBinop_TyeqGB07;
  HvTable hTable_uE3Ot1l8;
  ControlBinop cBinop_ZflEpHtB;
  ControlTabhead cTabhead_6Vy8nZVe;
  ControlVar cVar_Mf7QKgUx;
  ControlDelay cDelay_KAvz7USG;
  ControlDelay cDelay_3VaqIJDR;
  ControlBinop cBinop_YNxW4vml;
  ControlBinop cBinop_jGV7Kqw1;
  ControlBinop cBinop_aja27uYt;
  ControlBinop cBinop_oX2lntrp;
  ControlBinop cBinop_brcAl4oy;
  ControlBinop cBinop_nDfllkRe;
  ControlDelay cDelay_j4ukQrjq;
  ControlDelay cDelay_fNgTCjFU;
  ControlBinop cBinop_LiZWSINr;
  HvTable hTable_DrAvi7Sc;
  ControlBinop cBinop_OXHGQKTG;
  ControlTabhead cTabhead_zyHrbWra;
  ControlVar cVar_bgjx0mgk;
  ControlDelay cDelay_UIj6a4jk;
  ControlDelay cDelay_ZbOa7VDi;
  ControlBinop cBinop_vwkI5CYg;
  ControlBinop cBinop_kWDrr42H;
  ControlBinop cBinop_b8fugLPa;
  ControlBinop cBinop_QYzZGBBV;
  ControlBinop cBinop_0csjVuHV;
  ControlBinop cBinop_roQ4Qwio;
  ControlDelay cDelay_Px84b0no;
  ControlDelay cDelay_9tjciN2j;
  ControlBinop cBinop_OimAC3rd;
  HvTable hTable_2WS3L7y9;
  ControlBinop cBinop_rmgAIBEl;
  ControlTabhead cTabhead_20BNRcIp;
  ControlVar cVar_zzQBv86M;
  ControlDelay cDelay_vCv9eIP6;
  ControlDelay cDelay_bP9ZfhRf;
  ControlBinop cBinop_SnEBMlYc;
  ControlBinop cBinop_udXl7t7m;
  ControlBinop cBinop_4i9pubG8;
  ControlBinop cBinop_tqxpDGic;
  ControlBinop cBinop_fdFTHIZy;
  ControlBinop cBinop_llnytlO3;
  ControlDelay cDelay_fflkwnoD;
  ControlDelay cDelay_nRjebdX3;
  ControlBinop cBinop_dsQPZ6o2;
  HvTable hTable_j7wVbqKq;
  ControlBinop cBinop_4WvVU3D5;
  ControlTabhead cTabhead_ojFAOURY;
  ControlVar cVar_ESqy9KLJ;
  ControlDelay cDelay_ISDAUf0Y;
  ControlDelay cDelay_qoy4b32I;
  ControlBinop cBinop_bzMlKF7P;
  ControlBinop cBinop_s1lLdTT6;
  ControlBinop cBinop_XojDhFOY;
  ControlBinop cBinop_FnOPDHcS;
  ControlBinop cBinop_KPLMlns5;
  ControlBinop cBinop_k7oNpgJL;
  ControlDelay cDelay_MYe6A5UG;
  ControlDelay cDelay_Cdv7eGzd;
  ControlBinop cBinop_9Ws7xr6D;
  HvTable hTable_R3bW1ryO;
  ControlBinop cBinop_NbkVlCZ0;
  ControlTabhead cTabhead_3Z4GP1lw;
  ControlVar cVar_1GhhzQiX;
  ControlDelay cDelay_H8Gx4Ne0;
  ControlDelay cDelay_Kc2Mgbkx;
  ControlBinop cBinop_VBiHMfQ2;
  ControlBinop cBinop_j7F6pcSZ;
  ControlBinop cBinop_sg5CTzNp;
  ControlBinop cBinop_OPvv6QhH;
  ControlBinop cBinop_1TmAYPJ9;
  ControlBinop cBinop_KOyAKbne;
  ControlVar cVar_XToIk3cI;
  ControlVar cVar_xH7yhFLM;
  ControlPack cPack_nPkX560h;
  ControlVar cVar_870tR97r;
  ControlBinop cBinop_v4aIcEEu;
  ControlBinop cBinop_qm9mdiGV;
  SignalVarf sVarf_ZQKv20K8;
  ControlBinop cBinop_1uNJKNyN;
  ControlBinop cBinop_NxWgp1RW;
  ControlBinop cBinop_eW8H9Y2U;
  SignalVarf sVarf_RvKIPYNP;
  ControlVar cVar_36Hdjr4O;
  ControlBinop cBinop_5bqI1w0a;
  ControlBinop cBinop_tJq7hsqs;
  SignalVarf sVarf_tHHlyqyZ;
  ControlBinop cBinop_rJPiPzuc;
  ControlBinop cBinop_zCwgdrpO;
  ControlBinop cBinop_dEdQvdbt;
  SignalVarf sVarf_BSaUrVwt;
  ControlVar cVar_VzFTSVBr;
  ControlBinop cBinop_Joq4HPhn;
  ControlBinop cBinop_COwCNYtw;
  SignalVarf sVarf_GJ8RYZCz;
  ControlBinop cBinop_UmyZoolH;
  ControlBinop cBinop_4bv02oBp;
  ControlBinop cBinop_PixbKoF5;
  SignalVarf sVarf_hTRYlyMl;
  ControlBinop cBinop_uB68DMSz;
  ControlBinop cBinop_gdkvByGa;
  ControlBinop cBinop_G3XpwHNJ;
  ControlDelay cDelay_FniIefJj;
  ControlVar cVar_HEIBQLRE;
  ControlBinop cBinop_Qrtx3T7c;
  ControlBinop cBinop_bCa55Dgs;
  ControlBinop cBinop_M7oZQur3;
  ControlVar cVar_wv8dTcxM;
  ControlVar cVar_lCuSMW0x;
  ControlIf cIf_9V1V6Fp4;
  ControlBinop cBinop_DSD6xFVT;
  ControlDelay cDelay_PsJaucOg;
  ControlDelay cDelay_abrmloQ2;
  ControlBinop cBinop_38Dq8IKh;
  HvTable hTable_qPv6SYuZ;
  ControlBinop cBinop_GUVMPm6m;
  ControlTabhead cTabhead_Qd19PyIl;
  ControlVar cVar_qLNXrpCm;
  ControlDelay cDelay_S0KJbk0R;
  ControlDelay cDelay_djPkvxid;
  ControlBinop cBinop_BhHweMHL;
  ControlBinop cBinop_ipNUcMi8;
  ControlBinop cBinop_Svo2ojuC;
  ControlBinop cBinop_jCMoAAiZ;
  ControlBinop cBinop_6iD7Ntn5;
  ControlBinop cBinop_3H9BCyXn;
  ControlVar cVar_zceXu0z1;
  ControlVar cVar_wwjyLONC;
  ControlVar cVar_1kM9Lyjj;
  ControlVar cVar_8eA3mzTq;
  ControlVar cVar_f5s8lD5r;
  ControlVar cVar_EhZoxPnC;
  ControlIf cIf_uKUdecVW;
  ControlBinop cBinop_tKpKF4cO;
  ControlVar cVar_fohi0EP4;
  ControlIf cIf_a5DhQn8d;
  ControlBinop cBinop_XhP4OtiB;
  ControlSlice cSlice_h8wN5t0q;
  ControlSlice cSlice_raZiFjZB;
  ControlVar cVar_qBHkjBEJ;
  ControlIf cIf_E51ZYIw9;
  ControlBinop cBinop_DU8eV5KV;
  ControlIf cIf_dUeJW8P0;
  ControlIf cIf_8Gs21bY2;
  ControlIf cIf_E6quI8sN;
  ControlIf cIf_EoviPapw;
  ControlIf cIf_PCRtKCLF;
  SignalVarf sVarf_cEE2hDdx;
  ControlBinop cBinop_4YUXW1Ft;
  ControlBinop cBinop_pooyA0ml;
  ControlBinop cBinop_gTgtg2x7;
  ControlBinop cBinop_JoeXyhuP;
  SignalVarf sVarf_8xp9QnxE;
  ControlBinop cBinop_BAQEzUDV;
  ControlBinop cBinop_wYd4cp7n;
  SignalVarf sVarf_zPWMMrq9;
  SignalVarf sVarf_hVfbTIFr;
  ControlBinop cBinop_CGasukQS;
  ControlBinop cBinop_wFuVYI6y;
  ControlBinop cBinop_jcf94T5Y;
  ControlBinop cBinop_PTQVqXil;
  ControlBinop cBinop_nOFPGKqD;
  ControlBinop cBinop_DRPxU21g;
  ControlBinop cBinop_uEthG7RL;
  ControlBinop cBinop_WEkHzUpG;
  ControlBinop cBinop_1xSf6IJV;
  ControlBinop cBinop_imJ3hHTn;
  ControlBinop cBinop_Ebl1qs5H;
  ControlBinop cBinop_XfPGrSpB;
  ControlBinop cBinop_Q96JIfcf;
};

#endif // _HEAVY_CONTEXT_CHAFFVERB_HPP_
