/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_ChaffVerb.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_ChaffVerb *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_ChaffVerb_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_ChaffVerb));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_ChaffVerb(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_ChaffVerb_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_ChaffVerb));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_ChaffVerb(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_ChaffVerb_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_ChaffVerb();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_ChaffVerb::Heavy_ChaffVerb(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sPhasor_k_init(&sPhasor_jqFAl0mu, 0.0f, sampleRate);
  numBytes += sLine_init(&sLine_adXc1aZq);
  numBytes += sLine_init(&sLine_w4AE0Pc3);
  numBytes += sTabhead_init(&sTabhead_llE3uGZ9, &hTable_XQCKfQ7C);
  numBytes += sTabread_init(&sTabread_BxOq9RFd, &hTable_XQCKfQ7C, false);
  numBytes += sTabread_init(&sTabread_1icfGVw7, &hTable_XQCKfQ7C, false);
  numBytes += sTabhead_init(&sTabhead_eSiD4ph9, &hTable_XQCKfQ7C);
  numBytes += sTabread_init(&sTabread_VgKBW2M2, &hTable_XQCKfQ7C, false);
  numBytes += sTabread_init(&sTabread_cBTnkZnp, &hTable_XQCKfQ7C, false);
  numBytes += sTabwrite_init(&sTabwrite_tSJrGowR, &hTable_XQCKfQ7C);
  numBytes += sRPole_init(&sRPole_9rrRq1bE);
  numBytes += sDel1_init(&sDel1_WutqWsYf);
  numBytes += sTabread_init(&sTabread_P8ehkYPp, &hTable_qPv6SYuZ, true);
  numBytes += sTabwrite_init(&sTabwrite_DcSXWpAy, &hTable_qPv6SYuZ);
  numBytes += sTabread_init(&sTabread_32892OHy, &hTable_7kBrnt8n, true);
  numBytes += sRPole_init(&sRPole_SINHaRIo);
  numBytes += sLine_init(&sLine_RHG7goVo);
  numBytes += sLine_init(&sLine_ynbCPTOR);
  numBytes += sTabread_init(&sTabread_XTMScFCN, &hTable_vXtBaWoj, true);
  numBytes += sTabread_init(&sTabread_M0VW0xTw, &hTable_uE3Ot1l8, true);
  numBytes += sTabread_init(&sTabread_eJqQW8jk, &hTable_DrAvi7Sc, true);
  numBytes += sTabread_init(&sTabread_roh7vvPE, &hTable_2WS3L7y9, true);
  numBytes += sTabread_init(&sTabread_myNO78PS, &hTable_R3bW1ryO, true);
  numBytes += sTabread_init(&sTabread_UI1hGaCm, &hTable_j7wVbqKq, true);
  numBytes += sTabwrite_init(&sTabwrite_SBUXmKRO, &hTable_vXtBaWoj);
  numBytes += sTabwrite_init(&sTabwrite_WbBLYnnu, &hTable_uE3Ot1l8);
  numBytes += sTabwrite_init(&sTabwrite_GWSzT4Ha, &hTable_DrAvi7Sc);
  numBytes += sTabwrite_init(&sTabwrite_F6KBU0Qs, &hTable_2WS3L7y9);
  numBytes += sTabwrite_init(&sTabwrite_OR6AOtRm, &hTable_j7wVbqKq);
  numBytes += sTabwrite_init(&sTabwrite_jDiXJTXV, &hTable_R3bW1ryO);
  numBytes += sTabread_init(&sTabread_th3G4Otl, &hTable_1xUNdlcx, true);
  numBytes += sRPole_init(&sRPole_szYy3G4Y);
  numBytes += sTabread_init(&sTabread_AE4mA9Hx, &hTable_nm3JUNrt, true);
  numBytes += sRPole_init(&sRPole_YJJdJTRL);
  numBytes += sTabread_init(&sTabread_X6xTsZnq, &hTable_rsPSl4Tm, true);
  numBytes += sRPole_init(&sRPole_yQ0RDj9k);
  numBytes += sTabwrite_init(&sTabwrite_MMvhf21d, &hTable_7kBrnt8n);
  numBytes += sTabwrite_init(&sTabwrite_YERfVzFy, &hTable_1xUNdlcx);
  numBytes += sTabwrite_init(&sTabwrite_O51OxZpp, &hTable_nm3JUNrt);
  numBytes += sTabwrite_init(&sTabwrite_Lw4JCPC8, &hTable_rsPSl4Tm);
  numBytes += sLine_init(&sLine_J29RWejQ);
  numBytes += cVar_init_f(&cVar_kTHyhiYy, 0.0f);
  numBytes += cVar_init_f(&cVar_vRXYPTzD, 0.0f);
  numBytes += cPack_init(&cPack_E9OvjDK4, 2, 0.0f, 200.0f);
  numBytes += cVar_init_f(&cVar_gtpSyf3M, 0.0f);
  numBytes += cPack_init(&cPack_7LjCRhx2, 2, 0.0f, 200.0f);
  numBytes += cVar_init_f(&cVar_Ioq1yAOj, 0.0f);
  numBytes += cVar_init_f(&cVar_PHxxbvLS, 0.0f);
  numBytes += cDelay_init(this, &cDelay_O65UfwkA, 0.0f);
  numBytes += cDelay_init(this, &cDelay_VcLRwIah, 0.0f);
  numBytes += hTable_init(&hTable_XQCKfQ7C, 256);
  numBytes += cVar_init_s(&cVar_gVigWLva, "del-1002-shifter");
  numBytes += sVarf_init(&sVarf_kyYyuJYL, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_7exNcQqJ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_SXxXcnZP, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_gN1ufwuj, "del-1002-shifter");
  numBytes += sVarf_init(&sVarf_wyF0t4Nh, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_7HLaK9Ca, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ibCuJfoF, 0.0f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_1p1qWNCX, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_3z5ORaK8, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_vMM3bEiQ, 0.0f);
  numBytes += cBinop_init(&cBinop_NwHadRgV, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_DtIkXdBW, 0.0f, 0.0f, false);
  numBytes += cRandom_init(&cRandom_wivvdnhO, 2088822092);
  numBytes += cSlice_init(&cSlice_fl9bGCII, 1, 1);
  numBytes += cDelay_init(this, &cDelay_VVKa8ii8, 0.0f);
  numBytes += cVar_init_f(&cVar_nknlzmzF, 5.0f);
  numBytes += cBinop_init(&cBinop_mq3muuyI, 0.0f); // __mul
  numBytes += cTabhead_init(&cTabhead_7rF397Ln, &hTable_7kBrnt8n);
  numBytes += cVar_init_s(&cVar_P7D9lUQL, "del-1052-del1");
  numBytes += cDelay_init(this, &cDelay_sON2ACiY, 58.6435f);
  numBytes += cDelay_init(this, &cDelay_bIag6k5E, 0.0f);
  numBytes += cBinop_init(&cBinop_i87XpHOk, 58.6435f); // __mul
  numBytes += cBinop_init(&cBinop_NUHmjaw3, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_wMaXloOH, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_2ZD99GJC, 0.0f); // __sub
  numBytes += cTabhead_init(&cTabhead_VA4Dpeln, &hTable_1xUNdlcx);
  numBytes += cVar_init_s(&cVar_duAmrU2D, "del-1052-del2");
  numBytes += cDelay_init(this, &cDelay_BeLuy1it, 69.4325f);
  numBytes += cDelay_init(this, &cDelay_FLt63fKl, 0.0f);
  numBytes += cBinop_init(&cBinop_WXw8IIYR, 69.4325f); // __mul
  numBytes += cBinop_init(&cBinop_xmjksoHB, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_qSb7oLea, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_upqOD3jx, 0.0f); // __sub
  numBytes += cTabhead_init(&cTabhead_XqHlMAIZ, &hTable_nm3JUNrt);
  numBytes += cVar_init_s(&cVar_UQx5Ua7V, "del-1052-del3");
  numBytes += cDelay_init(this, &cDelay_AQVZZgml, 74.5234f);
  numBytes += cDelay_init(this, &cDelay_aAaNTnw9, 0.0f);
  numBytes += cBinop_init(&cBinop_90swmuyA, 74.5234f); // __mul
  numBytes += cBinop_init(&cBinop_IVsbH4SK, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_3IH8BjUv, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_5XBWd3sJ, 0.0f); // __sub
  numBytes += cTabhead_init(&cTabhead_UAq06X24, &hTable_rsPSl4Tm);
  numBytes += cVar_init_s(&cVar_8J0IaKxO, "del-1052-del4");
  numBytes += cDelay_init(this, &cDelay_SMvEgPUF, 86.1244f);
  numBytes += cDelay_init(this, &cDelay_KPxlbWXO, 0.0f);
  numBytes += cBinop_init(&cBinop_XT5uGTEk, 86.1244f); // __mul
  numBytes += cBinop_init(&cBinop_StfOboQf, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_MP4FfcKz, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_x9fnkLkb, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_4kORenPA, 0.0f);
  numBytes += cDelay_init(this, &cDelay_ytjFawbk, 0.0f);
  numBytes += hTable_init(&hTable_7kBrnt8n, 256);
  numBytes += cDelay_init(this, &cDelay_C4wXfBeJ, 0.0f);
  numBytes += cDelay_init(this, &cDelay_Xlv7V6aR, 0.0f);
  numBytes += hTable_init(&hTable_1xUNdlcx, 256);
  numBytes += cDelay_init(this, &cDelay_hhAVud4i, 0.0f);
  numBytes += cDelay_init(this, &cDelay_OJotLSZG, 0.0f);
  numBytes += hTable_init(&hTable_nm3JUNrt, 256);
  numBytes += cDelay_init(this, &cDelay_NepzIRVJ, 0.0f);
  numBytes += cDelay_init(this, &cDelay_PGkuQft8, 0.0f);
  numBytes += hTable_init(&hTable_rsPSl4Tm, 256);
  numBytes += cPack_init(&cPack_wNA7kvlC, 2, 0.0f, 30.0f);
  numBytes += cPack_init(&cPack_JBiKGciB, 2, 0.0f, 50.0f);
  numBytes += cVar_init_f(&cVar_7ggzn5Xa, 22050.0f);
  numBytes += cBinop_init(&cBinop_K7l76Jf2, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_CERnyAlN, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_LkrWIftb, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_GeRuZH7Z, 0.0f);
  numBytes += cVar_init_f(&cVar_c6zEK3um, 0.0f);
  numBytes += cVar_init_f(&cVar_mwrwjSDQ, 0.0f);
  numBytes += cVar_init_f(&cVar_rEr8UQZ4, 0.0f);
  numBytes += cIf_init(&cIf_PcnMCFSg, false);
  numBytes += cDelay_init(this, &cDelay_ahxUkapM, 0.0f);
  numBytes += cDelay_init(this, &cDelay_sye1z9Wd, 0.0f);
  numBytes += hTable_init(&hTable_vXtBaWoj, 256);
  numBytes += cTabhead_init(&cTabhead_x2nIKaC8, &hTable_vXtBaWoj);
  numBytes += cVar_init_s(&cVar_jJcbCOKM, "del-1052-ref1");
  numBytes += cDelay_init(this, &cDelay_ZS0nhyOr, 43.5337f);
  numBytes += cDelay_init(this, &cDelay_lkFsyYNC, 0.0f);
  numBytes += cBinop_init(&cBinop_pICtUoFf, 43.5337f); // __mul
  numBytes += cBinop_init(&cBinop_PjHLNWo3, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_y4dljvy2, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_m2uQ3ZU7, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_A22Y5jMS, 0.0f);
  numBytes += cDelay_init(this, &cDelay_XVwWty9X, 0.0f);
  numBytes += hTable_init(&hTable_uE3Ot1l8, 256);
  numBytes += cTabhead_init(&cTabhead_6Vy8nZVe, &hTable_uE3Ot1l8);
  numBytes += cVar_init_s(&cVar_Mf7QKgUx, "del-1052-ref2");
  numBytes += cDelay_init(this, &cDelay_KAvz7USG, 25.796f);
  numBytes += cDelay_init(this, &cDelay_3VaqIJDR, 0.0f);
  numBytes += cBinop_init(&cBinop_YNxW4vml, 25.796f); // __mul
  numBytes += cBinop_init(&cBinop_aja27uYt, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_oX2lntrp, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_nDfllkRe, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_j4ukQrjq, 0.0f);
  numBytes += cDelay_init(this, &cDelay_fNgTCjFU, 0.0f);
  numBytes += hTable_init(&hTable_DrAvi7Sc, 256);
  numBytes += cTabhead_init(&cTabhead_zyHrbWra, &hTable_DrAvi7Sc);
  numBytes += cVar_init_s(&cVar_bgjx0mgk, "del-1052-ref3");
  numBytes += cDelay_init(this, &cDelay_UIj6a4jk, 19.392f);
  numBytes += cDelay_init(this, &cDelay_ZbOa7VDi, 0.0f);
  numBytes += cBinop_init(&cBinop_vwkI5CYg, 19.392f); // __mul
  numBytes += cBinop_init(&cBinop_b8fugLPa, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_QYzZGBBV, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_roQ4Qwio, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_Px84b0no, 0.0f);
  numBytes += cDelay_init(this, &cDelay_9tjciN2j, 0.0f);
  numBytes += hTable_init(&hTable_2WS3L7y9, 256);
  numBytes += cTabhead_init(&cTabhead_20BNRcIp, &hTable_2WS3L7y9);
  numBytes += cVar_init_s(&cVar_zzQBv86M, "del-1052-ref4");
  numBytes += cDelay_init(this, &cDelay_vCv9eIP6, 16.364f);
  numBytes += cDelay_init(this, &cDelay_bP9ZfhRf, 0.0f);
  numBytes += cBinop_init(&cBinop_SnEBMlYc, 16.364f); // __mul
  numBytes += cBinop_init(&cBinop_4i9pubG8, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_tqxpDGic, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_llnytlO3, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_fflkwnoD, 0.0f);
  numBytes += cDelay_init(this, &cDelay_nRjebdX3, 0.0f);
  numBytes += hTable_init(&hTable_j7wVbqKq, 256);
  numBytes += cTabhead_init(&cTabhead_ojFAOURY, &hTable_j7wVbqKq);
  numBytes += cVar_init_s(&cVar_ESqy9KLJ, "del-1052-ref6");
  numBytes += cDelay_init(this, &cDelay_ISDAUf0Y, 4.2546f);
  numBytes += cDelay_init(this, &cDelay_qoy4b32I, 0.0f);
  numBytes += cBinop_init(&cBinop_bzMlKF7P, 4.2546f); // __mul
  numBytes += cBinop_init(&cBinop_XojDhFOY, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_FnOPDHcS, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_k7oNpgJL, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_MYe6A5UG, 0.0f);
  numBytes += cDelay_init(this, &cDelay_Cdv7eGzd, 0.0f);
  numBytes += hTable_init(&hTable_R3bW1ryO, 256);
  numBytes += cTabhead_init(&cTabhead_3Z4GP1lw, &hTable_R3bW1ryO);
  numBytes += cVar_init_s(&cVar_1GhhzQiX, "del-1052-ref5");
  numBytes += cDelay_init(this, &cDelay_H8Gx4Ne0, 7.645f);
  numBytes += cDelay_init(this, &cDelay_Kc2Mgbkx, 0.0f);
  numBytes += cBinop_init(&cBinop_VBiHMfQ2, 7.645f); // __mul
  numBytes += cBinop_init(&cBinop_sg5CTzNp, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_OPvv6QhH, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_KOyAKbne, 0.0f); // __sub
  numBytes += cVar_init_f(&cVar_XToIk3cI, 0.0f);
  numBytes += cVar_init_f(&cVar_xH7yhFLM, 0.0f);
  numBytes += cPack_init(&cPack_nPkX560h, 2, 0.0f, 50.0f);
  numBytes += cVar_init_f(&cVar_870tR97r, 22050.0f);
  numBytes += cBinop_init(&cBinop_v4aIcEEu, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_ZQKv20K8, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_RvKIPYNP, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_36Hdjr4O, 22050.0f);
  numBytes += cBinop_init(&cBinop_5bqI1w0a, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_tHHlyqyZ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_BSaUrVwt, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_VzFTSVBr, 22050.0f);
  numBytes += cBinop_init(&cBinop_Joq4HPhn, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_GJ8RYZCz, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_hTRYlyMl, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_FniIefJj, 0.0f);
  numBytes += cVar_init_f(&cVar_HEIBQLRE, 1000.0f);
  numBytes += cBinop_init(&cBinop_M7oZQur3, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_wv8dTcxM, 0.0f);
  numBytes += cVar_init_f(&cVar_lCuSMW0x, 0.0f);
  numBytes += cIf_init(&cIf_9V1V6Fp4, false);
  numBytes += cDelay_init(this, &cDelay_PsJaucOg, 0.0f);
  numBytes += cDelay_init(this, &cDelay_abrmloQ2, 0.0f);
  numBytes += hTable_init(&hTable_qPv6SYuZ, 256);
  numBytes += cTabhead_init(&cTabhead_Qd19PyIl, &hTable_qPv6SYuZ);
  numBytes += cVar_init_s(&cVar_qLNXrpCm, "del-1001-del1");
  numBytes += cDelay_init(this, &cDelay_S0KJbk0R, 150.0f);
  numBytes += cDelay_init(this, &cDelay_djPkvxid, 0.0f);
  numBytes += cBinop_init(&cBinop_BhHweMHL, 150.0f); // __mul
  numBytes += cBinop_init(&cBinop_Svo2ojuC, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_jCMoAAiZ, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_3H9BCyXn, 0.0f); // __sub
  numBytes += cVar_init_f(&cVar_zceXu0z1, 0.0f);
  numBytes += cVar_init_f(&cVar_wwjyLONC, 0.0f);
  numBytes += cVar_init_f(&cVar_1kM9Lyjj, 0.0f);
  numBytes += cVar_init_f(&cVar_8eA3mzTq, 0.0f);
  numBytes += cVar_init_f(&cVar_f5s8lD5r, 0.0f);
  numBytes += cVar_init_f(&cVar_EhZoxPnC, 0.0f);
  numBytes += cIf_init(&cIf_uKUdecVW, false);
  numBytes += cVar_init_f(&cVar_fohi0EP4, 0.0f);
  numBytes += cIf_init(&cIf_a5DhQn8d, false);
  numBytes += cSlice_init(&cSlice_h8wN5t0q, 1, -1);
  numBytes += cSlice_init(&cSlice_raZiFjZB, 1, -1);
  numBytes += cVar_init_f(&cVar_qBHkjBEJ, 0.0f);
  numBytes += cIf_init(&cIf_E51ZYIw9, false);
  numBytes += cBinop_init(&cBinop_DU8eV5KV, 0.0f); // __neq
  numBytes += cIf_init(&cIf_dUeJW8P0, false);
  numBytes += cIf_init(&cIf_8Gs21bY2, false);
  numBytes += cIf_init(&cIf_E6quI8sN, false);
  numBytes += cIf_init(&cIf_EoviPapw, true);
  numBytes += cIf_init(&cIf_PCRtKCLF, false);
  numBytes += sVarf_init(&sVarf_cEE2hDdx, 1.0f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_gTgtg2x7, 4.0f); // __unimod
  numBytes += sVarf_init(&sVarf_8xp9QnxE, 0.1f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_BAQEzUDV, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_wYd4cp7n, 0.0f); // __add
  numBytes += sVarf_init(&sVarf_zPWMMrq9, 0.65f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_hVfbTIFr, 0.55f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_wFuVYI6y, 1.0f); // __mul
  numBytes += cBinop_init(&cBinop_1xSf6IJV, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_imJ3hHTn, 1.0f); // __mul
  numBytes += cBinop_init(&cBinop_Ebl1qs5H, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_XfPGrSpB, 1.0f); // __mul
  numBytes += cBinop_init(&cBinop_Q96JIfcf, 0.0f); // __add
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_ChaffVerb::~Heavy_ChaffVerb() {
  cPack_free(&cPack_E9OvjDK4);
  cPack_free(&cPack_7LjCRhx2);
  hTable_free(&hTable_XQCKfQ7C);
  hTable_free(&hTable_7kBrnt8n);
  hTable_free(&hTable_1xUNdlcx);
  hTable_free(&hTable_nm3JUNrt);
  hTable_free(&hTable_rsPSl4Tm);
  cPack_free(&cPack_wNA7kvlC);
  cPack_free(&cPack_JBiKGciB);
  hTable_free(&hTable_vXtBaWoj);
  hTable_free(&hTable_uE3Ot1l8);
  hTable_free(&hTable_DrAvi7Sc);
  hTable_free(&hTable_2WS3L7y9);
  hTable_free(&hTable_j7wVbqKq);
  hTable_free(&hTable_R3bW1ryO);
  cPack_free(&cPack_nPkX560h);
  hTable_free(&hTable_qPv6SYuZ);
}

HvTable *Heavy_ChaffVerb::getTableForHash(hv_uint32_t tableHash) {switch (tableHash) {
    case 0xA1445E2C: return &hTable_XQCKfQ7C; // del-1002-shifter
    case 0xAAA0EB60: return &hTable_7kBrnt8n; // del-1052-del1
    case 0xA2AC524D: return &hTable_1xUNdlcx; // del-1052-del2
    case 0xE36A35B: return &hTable_nm3JUNrt; // del-1052-del3
    case 0x48CE0509: return &hTable_rsPSl4Tm; // del-1052-del4
    case 0xE34D6E72: return &hTable_vXtBaWoj; // del-1052-ref1
    case 0x6A1027AB: return &hTable_uE3Ot1l8; // del-1052-ref2
    case 0xA37C6D49: return &hTable_DrAvi7Sc; // del-1052-ref3
    case 0xCEFE5FE5: return &hTable_2WS3L7y9; // del-1052-ref4
    case 0x48EB8BBB: return &hTable_j7wVbqKq; // del-1052-ref6
    case 0xCC6F73D5: return &hTable_R3bW1ryO; // del-1052-ref5
    case 0xED65564F: return &hTable_qPv6SYuZ; // del-1001-del1
    default: return nullptr;
  }
}

void Heavy_ChaffVerb::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0x1F30993F: { // A__LFO_Period
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_LagiHFgr_sendMessage);
      break;
    }
    case 0x1A2B8E9F: { // A__LFO_Steps_Scale__Type2
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_PO6ifWxZ_sendMessage);
      break;
    }
    case 0xBE3344C8: { // A__LFO_Steps__Type2
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Pj7QEql7_sendMessage);
      break;
    }
    case 0x7369936E: { // A__LFO_Switch
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_wcthEm55_sendMessage);
      break;
    }
    case 0xD64CFD23: { // A__LFO_type
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_7uzdluK5_sendMessage);
      break;
    }
    case 0x51447E19: { // B__General_Offset
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_9abq3WiE_sendMessage);
      break;
    }
    case 0xA10FCFC4: { // B__General_Scale
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_9itnJKNa_sendMessage);
      break;
    }
    case 0x7EFB8E46: { // C__Random_LFO_Offset
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_z6tYpPbN_sendMessage);
      break;
    }
    case 0xE6223016: { // C__Random_LFO_Period
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_CLixaqgH_sendMessage);
      break;
    }
    case 0x3281900D: { // C__Random_LFO_Scale
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_c7kesexW_sendMessage);
      break;
    }
    case 0x6150BC53: { // C__Random_LFO_Switch
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_sC0lFmd6_sendMessage);
      break;
    }
    case 0x9CBB1BF3: { // D__Shift_Microtone
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_w3eOFv0L_sendMessage);
      break;
    }
    case 0x4439D71: { // D__Shift_Transpose
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_j6ciMmg6_sendMessage);
      break;
    }
    case 0x890283C2: { // E__Fx_Level
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_jHrKk7A3_sendMessage);
      break;
    }
    case 0x12962685: { // E__HiPass_Freq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_gQXAcfx6_sendMessage);
      break;
    }
    case 0x183CFEE5: { // E__Shift_Delay
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_kDKz0ruv_sendMessage);
      break;
    }
    case 0x57FF40DB: { // E__Shift_Window
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_FZeOcAZs_sendMessage);
      break;
    }
    case 0x69A91334: { // F__FX_Delay
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_YCcSeHsB_sendMessage);
      break;
    }
    case 0x68D029F7: { // F__FX_Delay_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_DHhSlRP0_sendMessage);
      break;
    }
    case 0xD63693D0: { // Mix__Dry_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Md9Z4CsW_sendMessage);
      break;
    }
    case 0x1FC3C02C: { // Mix__Dry_Vol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_KKh5G0Rb_sendMessage);
      break;
    }
    case 0x58653D84: { // Mix__Reverb_Level
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_A1LPCwC8_sendMessage);
      break;
    }
    case 0xE764F673: { // Mix__Reverb_Vol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_j1eSrFq1_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_WHp89IcV_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_ChaffVerb::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "A__LFO_Period";
        info->hash = 0x1F30993F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 4000.0f;
        info->defaultVal = 1500.0f;
        break;
      }
      case 1: {
        info->name = "A__LFO_Steps_Scale__Type2";
        info->hash = 0x1A2B8E9F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -5.0f;
        info->maxVal = 5.0f;
        info->defaultVal = 1.0f;
        break;
      }
      case 2: {
        info->name = "A__LFO_Steps__Type2";
        info->hash = 0xBE3344C8;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 2.0f;
        info->maxVal = 10.0f;
        info->defaultVal = 4.0f;
        break;
      }
      case 3: {
        info->name = "A__LFO_Switch";
        info->hash = 0x7369936E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 4: {
        info->name = "A__LFO_type";
        info->hash = 0xD64CFD23;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 2.99f;
        info->defaultVal = 0.0f;
        break;
      }
      case 5: {
        info->name = "B__General_Offset";
        info->hash = 0x51447E19;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -2.0f;
        info->maxVal = 2.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 6: {
        info->name = "B__General_Scale";
        info->hash = 0xA10FCFC4;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -7.0f;
        info->maxVal = 7.0f;
        info->defaultVal = 1.0f;
        break;
      }
      case 7: {
        info->name = "C__Random_LFO_Offset";
        info->hash = 0x7EFB8E46;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -2.0f;
        info->maxVal = 2.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 8: {
        info->name = "C__Random_LFO_Period";
        info->hash = 0xE6223016;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 4000.0f;
        info->defaultVal = 1500.0f;
        break;
      }
      case 9: {
        info->name = "C__Random_LFO_Scale";
        info->hash = 0x3281900D;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -7.0f;
        info->maxVal = 7.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 10: {
        info->name = "C__Random_LFO_Switch";
        info->hash = 0x6150BC53;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 11: {
        info->name = "D__Shift_Microtone";
        info->hash = 0x9CBB1BF3;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -1.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 12: {
        info->name = "D__Shift_Transpose";
        info->hash = 0x4439D71;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -36.0f;
        info->maxVal = 36.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 13: {
        info->name = "E__Fx_Level";
        info->hash = 0x890283C2;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.7f;
        break;
      }
      case 14: {
        info->name = "E__HiPass_Freq";
        info->hash = 0x12962685;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 100.0f;
        info->maxVal = 2500.0f;
        info->defaultVal = 800.0f;
        break;
      }
      case 15: {
        info->name = "E__Shift_Delay";
        info->hash = 0x183CFEE5;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 500.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 16: {
        info->name = "E__Shift_Window";
        info->hash = 0x57FF40DB;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 3500.0f;
        info->defaultVal = 1000.0f;
        break;
      }
      case 17: {
        info->name = "F__FX_Delay";
        info->hash = 0x69A91334;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 2000.0f;
        info->defaultVal = 500.0f;
        break;
      }
      case 18: {
        info->name = "F__FX_Delay_Feedback";
        info->hash = 0x68D029F7;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.97f;
        info->defaultVal = 0.65f;
        break;
      }
      case 19: {
        info->name = "Mix__Dry_Mix";
        info->hash = 0xD63693D0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.45f;
        break;
      }
      case 20: {
        info->name = "Mix__Dry_Vol";
        info->hash = 0x1FC3C02C;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.1f;
        break;
      }
      case 21: {
        info->name = "Mix__Reverb_Level";
        info->hash = 0x58653D84;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.85f;
        break;
      }
      case 22: {
        info->name = "Mix__Reverb_Vol";
        info->hash = 0xE764F673;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.5f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 23;
}



/*
 * Send Function Implementations
 */


void Heavy_ChaffVerb::cVar_kTHyhiYy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.05776f, 0, m, &cBinop_LFuFZnjz_sendMessage);
}

void Heavy_ChaffVerb::cVar_vRXYPTzD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_L7PwWTLk_sendMessage);
}

void Heavy_ChaffVerb::cPack_E9OvjDK4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sLine_onMessage(_c, &Context(_c)->sLine_adXc1aZq, 0, m, NULL);
}

void Heavy_ChaffVerb::cUnop_IV0omvj8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_gtpSyf3M, 0, m, &cVar_gtpSyf3M_sendMessage);
}

void Heavy_ChaffVerb::cBinop_zU6UZf5K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_EXP, m, &cUnop_IV0omvj8_sendMessage);
}

void Heavy_ChaffVerb::cVar_gtpSyf3M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_PqS42mNX_sendMessage);
}

void Heavy_ChaffVerb::cPack_7LjCRhx2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sLine_onMessage(_c, &Context(_c)->sLine_w4AE0Pc3, 0, m, NULL);
}

void Heavy_ChaffVerb::cVar_Ioq1yAOj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.5f, 0, m, &cBinop_CxI6axwB_sendMessage);
}

void Heavy_ChaffVerb::cVar_PHxxbvLS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sPhasor_k_onMessage(_c, &Context(_c)->sPhasor_jqFAl0mu, 0, m);
}

void Heavy_ChaffVerb::cMsg_Y46mOHFG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_fzv1Yl3O_sendMessage);
}

void Heavy_ChaffVerb::cSystem_fzv1Yl3O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_WeoEFzc7_sendMessage);
}

void Heavy_ChaffVerb::cDelay_O65UfwkA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_O65UfwkA, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_VcLRwIah, 0, m, &cDelay_VcLRwIah_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_O65UfwkA, 0, m, &cDelay_O65UfwkA_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_tSJrGowR, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_VcLRwIah_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_VcLRwIah, m);
  cMsg_IyL3cMF2_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_P4Yuyhcj_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_0F7RFBDi_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_eu459mF1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GMYLoeOC_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_XQCKfQ7C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_odJCZim8_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_O65UfwkA, 2, m, &cDelay_O65UfwkA_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_eHLsNxXe_sendMessage);
}

void Heavy_ChaffVerb::cMsg_GMYLoeOC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_XQCKfQ7C, 0, m, &hTable_XQCKfQ7C_sendMessage);
}

void Heavy_ChaffVerb::cBinop_WeoEFzc7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_eu459mF1_sendMessage);
}

void Heavy_ChaffVerb::cMsg_IyL3cMF2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_XQCKfQ7C, 0, m, &hTable_XQCKfQ7C_sendMessage);
}

void Heavy_ChaffVerb::cCast_eHLsNxXe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_O65UfwkA, 0, m, &cDelay_O65UfwkA_sendMessage);
}

void Heavy_ChaffVerb::cMsg_odJCZim8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_VcLRwIah, 2, m, &cDelay_VcLRwIah_sendMessage);
}

void Heavy_ChaffVerb::cMsg_0F7RFBDi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_tSJrGowR, 1, m, NULL);
}

void Heavy_ChaffVerb::cMsg_jNee8IXR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_7BDOuLpY_sendMessage);
}

void Heavy_ChaffVerb::cSystem_7BDOuLpY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_BOBmKPLH_sendMessage);
}

void Heavy_ChaffVerb::cVar_gVigWLva_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vMMdyqPx_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSystem_NtBtT15u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_Zd0YEuzd_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_kyYyuJYL, m);
}

void Heavy_ChaffVerb::cBinop_BOBmKPLH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_7exNcQqJ, m);
}

void Heavy_ChaffVerb::cMsg_vMMdyqPx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_NtBtT15u_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Zd0YEuzd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_SXxXcnZP, m);
}

void Heavy_ChaffVerb::cMsg_QTZvosFJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_AFOnokSZ_sendMessage);
}

void Heavy_ChaffVerb::cSystem_AFOnokSZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_b46K0o3p_sendMessage);
}

void Heavy_ChaffVerb::cVar_gN1ufwuj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gV2tVuJB_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSystem_ytRMkczW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_65aDF6Ko_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_wyF0t4Nh, m);
}

void Heavy_ChaffVerb::cBinop_b46K0o3p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_7HLaK9Ca, m);
}

void Heavy_ChaffVerb::cMsg_gV2tVuJB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ytRMkczW_sendMessage);
}

void Heavy_ChaffVerb::cBinop_65aDF6Ko_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_ibCuJfoF, m);
}

void Heavy_ChaffVerb::cBinop_1p1qWNCX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_PHxxbvLS, 0, m, &cVar_PHxxbvLS_sendMessage);
}

void Heavy_ChaffVerb::cBinop_XySsshbo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sLq86R90_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IkKvg41s_sendMessage);
}

void Heavy_ChaffVerb::cCast_sLq86R90_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1p1qWNCX, HV_BINOP_DIVIDE, 1, m, &cBinop_1p1qWNCX_sendMessage);
}

void Heavy_ChaffVerb::cCast_IkKvg41s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1p1qWNCX, HV_BINOP_DIVIDE, 0, m, &cBinop_1p1qWNCX_sendMessage);
}

void Heavy_ChaffVerb::cBinop_PqS42mNX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_MMuVIpcN_sendMessage);
}

void Heavy_ChaffVerb::cBinop_LFuFZnjz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 87.3365f, 0, m, &cBinop_zU6UZf5K_sendMessage);
}

void Heavy_ChaffVerb::cBinop_MMuVIpcN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1p1qWNCX, HV_BINOP_DIVIDE, 0, m, &cBinop_1p1qWNCX_sendMessage);
}

void Heavy_ChaffVerb::cBinop_CxI6axwB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_7LjCRhx2, 0, m, &cPack_7LjCRhx2_sendMessage);
}

void Heavy_ChaffVerb::cBinop_L7PwWTLk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.001f, 0, m, &cBinop_XySsshbo_sendMessage);
  cPack_onMessage(_c, &Context(_c)->cPack_E9OvjDK4, 0, m, &cPack_E9OvjDK4_sendMessage);
}

void Heavy_ChaffVerb::cUnop_rrlKy3jZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_8Gs21bY2, 0, m, &cIf_8Gs21bY2_sendMessage);
}

void Heavy_ChaffVerb::cSwitchcase_c15KAOQs_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sRsnxOwC_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4ytw6kOR_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_c1U6NqAp_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cCast_sRsnxOwC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yU9uGtZO_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cCast_4ytw6kOR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wBFSo0Gv_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cCast_c1U6NqAp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Q8wZh0Bb_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_XonMbqI4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_4b9mBZ9S_sendMessage);
}

void Heavy_ChaffVerb::cBinop_4b9mBZ9S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_Q0I0k36I_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_Itw6bo8C_sendMessage);
}

void Heavy_ChaffVerb::cVar_vMM3bEiQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_bUIEEGZi_sendMessage);
}

void Heavy_ChaffVerb::cMsg_F8HtLmXE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_gY2nUprh_sendMessage);
}

void Heavy_ChaffVerb::cSystem_gY2nUprh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NwHadRgV, HV_BINOP_DIVIDE, 1, m, &cBinop_NwHadRgV_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Q0I0k36I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_WxhuPKLg_sendMessage);
}

void Heavy_ChaffVerb::cBinop_WxhuPKLg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_DtIkXdBW, m);
}

void Heavy_ChaffVerb::cMsg_yC7F09W0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_OwNHd610_sendMessage);
}

void Heavy_ChaffVerb::cBinop_OwNHd610_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_XonMbqI4_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Itw6bo8C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_3z5ORaK8, m);
}

void Heavy_ChaffVerb::cBinop_bUIEEGZi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_JpXaKS9z_sendMessage);
}

void Heavy_ChaffVerb::cBinop_JpXaKS9z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NwHadRgV, HV_BINOP_DIVIDE, 0, m, &cBinop_NwHadRgV_sendMessage);
}

void Heavy_ChaffVerb::cBinop_NwHadRgV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yC7F09W0_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_djRIBQzX_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7E64BD01: { // "seed"
      cSlice_onMessage(_c, &Context(_c)->cSlice_fl9bGCII, 0, m, &cSlice_fl9bGCII_sendMessage);
      break;
    }
    default: {
      cRandom_onMessage(_c, &Context(_c)->cRandom_wivvdnhO, 0, m, &cRandom_wivvdnhO_sendMessage);
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_F7c8q80i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_FLOOR, m, &cUnop_VeYiluKZ_sendMessage);
}

void Heavy_ChaffVerb::cUnop_VeYiluKZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 50.0f, 0, m, &cBinop_pooyA0ml_sendMessage);
}

void Heavy_ChaffVerb::cRandom_wivvdnhO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 100.0f, 0, m, &cBinop_F7c8q80i_sendMessage);
}

void Heavy_ChaffVerb::cSlice_fl9bGCII_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cRandom_onMessage(_c, &Context(_c)->cRandom_wivvdnhO, 1, m, &cRandom_wivvdnhO_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cSwitchcase_aQukJHnF_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cMsg_2yH11CP3_sendMessage(_c, 0, m);
      break;
    }
    case 0x7A5B032D: { // "stop"
      cMsg_2yH11CP3_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oZLLZneR_sendMessage);
      break;
    }
  }
}

void Heavy_ChaffVerb::cDelay_VVKa8ii8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_VVKa8ii8, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_VVKa8ii8, 0, m, &cDelay_VVKa8ii8_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_wv8dTcxM, 0, m, &cVar_wv8dTcxM_sendMessage);
}

void Heavy_ChaffVerb::cCast_oZLLZneR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2yH11CP3_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_VVKa8ii8, 0, m, &cDelay_VVKa8ii8_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_wv8dTcxM, 0, m, &cVar_wv8dTcxM_sendMessage);
}

void Heavy_ChaffVerb::cMsg_yLnEQeGy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_QrVWT3KK_sendMessage);
}

void Heavy_ChaffVerb::cSystem_QrVWT3KK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_mMt7NDmO_sendMessage);
}

void Heavy_ChaffVerb::cVar_nknlzmzF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mq3muuyI, HV_BINOP_MULTIPLY, 0, m, &cBinop_mq3muuyI_sendMessage);
}

void Heavy_ChaffVerb::cMsg_2yH11CP3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_VVKa8ii8, 0, m, &cDelay_VVKa8ii8_sendMessage);
}

void Heavy_ChaffVerb::cBinop_TOoj19kX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_VVKa8ii8, 2, m, &cDelay_VVKa8ii8_sendMessage);
}

void Heavy_ChaffVerb::cBinop_mMt7NDmO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mq3muuyI, HV_BINOP_MULTIPLY, 1, m, &cBinop_mq3muuyI_sendMessage);
}

void Heavy_ChaffVerb::cBinop_mq3muuyI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_TOoj19kX_sendMessage);
}

void Heavy_ChaffVerb::cTabhead_7rF397Ln_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NUHmjaw3, HV_BINOP_SUBTRACT, 0, m, &cBinop_NUHmjaw3_sendMessage);
}

void Heavy_ChaffVerb::cMsg_BbvRIzj2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Dq4Fxu8k_sendMessage);
}

void Heavy_ChaffVerb::cSystem_Dq4Fxu8k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_Rcncf8Ya_sendMessage);
}

void Heavy_ChaffVerb::cVar_P7D9lUQL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1OjX8Q5j_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_sON2ACiY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_sON2ACiY, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_bIag6k5E, 0, m, &cDelay_bIag6k5E_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_32892OHy, 0, m, &sTabread_32892OHy_sendMessage);
}

void Heavy_ChaffVerb::cDelay_bIag6k5E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_bIag6k5E, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_32892OHy, 0, m, &sTabread_32892OHy_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_bIag6k5E, 0, m, &cDelay_bIag6k5E_sendMessage);
}

void Heavy_ChaffVerb::sTabread_32892OHy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_2ZD99GJC, HV_BINOP_SUBTRACT, 0, m, &cBinop_2ZD99GJC_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_i87XpHOk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wMaXloOH, HV_BINOP_MAX, 0, m, &cBinop_wMaXloOH_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Rcncf8Ya_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_i87XpHOk, HV_BINOP_MULTIPLY, 0, m, &cBinop_i87XpHOk_sendMessage);
}

void Heavy_ChaffVerb::cBinop_NUHmjaw3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xmzERKTU_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_32892OHy, 0, m, &sTabread_32892OHy_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_o3JRgC00_sendMessage);
}

void Heavy_ChaffVerb::cSystem_zK6UDMNe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2ZD99GJC, HV_BINOP_SUBTRACT, 1, m, &cBinop_2ZD99GJC_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_bIag6k5E, 2, m, &cDelay_bIag6k5E_sendMessage);
}

void Heavy_ChaffVerb::cMsg_1OjX8Q5j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_zK6UDMNe_sendMessage);
}

void Heavy_ChaffVerb::cMsg_xmzERKTU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_sON2ACiY, 0, m, &cDelay_sON2ACiY_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_bIag6k5E, 0, m, &cDelay_bIag6k5E_sendMessage);
}

void Heavy_ChaffVerb::cMsg_kdT6nrmn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_wMaXloOH, HV_BINOP_MAX, 1, m, &cBinop_wMaXloOH_sendMessage);
}

void Heavy_ChaffVerb::cBinop_wMaXloOH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NUHmjaw3, HV_BINOP_SUBTRACT, 1, m, &cBinop_NUHmjaw3_sendMessage);
}

void Heavy_ChaffVerb::cCast_o3JRgC00_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_sON2ACiY, 0, m, &cDelay_sON2ACiY_sendMessage);
}

void Heavy_ChaffVerb::cBinop_F5Rz4Uhn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_sON2ACiY, 2, m, &cDelay_sON2ACiY_sendMessage);
}

void Heavy_ChaffVerb::cBinop_2ZD99GJC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_F5Rz4Uhn_sendMessage);
}

void Heavy_ChaffVerb::cCast_ZUsrwxoA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_P7D9lUQL, 0, m, &cVar_P7D9lUQL_sendMessage);
  cMsg_BbvRIzj2_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_7rF397Ln, 0, m, &cTabhead_7rF397Ln_sendMessage);
}

void Heavy_ChaffVerb::cTabhead_VA4Dpeln_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xmjksoHB, HV_BINOP_SUBTRACT, 0, m, &cBinop_xmjksoHB_sendMessage);
}

void Heavy_ChaffVerb::cMsg_N4z46cdl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_XOS5kXk3_sendMessage);
}

void Heavy_ChaffVerb::cSystem_XOS5kXk3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_ZxQ9lK3d_sendMessage);
}

void Heavy_ChaffVerb::cVar_duAmrU2D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JJr6wQEc_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_BeLuy1it_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_BeLuy1it, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_FLt63fKl, 0, m, &cDelay_FLt63fKl_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_th3G4Otl, 0, m, &sTabread_th3G4Otl_sendMessage);
}

void Heavy_ChaffVerb::cDelay_FLt63fKl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_FLt63fKl, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_th3G4Otl, 0, m, &sTabread_th3G4Otl_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_FLt63fKl, 0, m, &cDelay_FLt63fKl_sendMessage);
}

void Heavy_ChaffVerb::sTabread_th3G4Otl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_upqOD3jx, HV_BINOP_SUBTRACT, 0, m, &cBinop_upqOD3jx_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_WXw8IIYR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qSb7oLea, HV_BINOP_MAX, 0, m, &cBinop_qSb7oLea_sendMessage);
}

void Heavy_ChaffVerb::cBinop_ZxQ9lK3d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WXw8IIYR, HV_BINOP_MULTIPLY, 0, m, &cBinop_WXw8IIYR_sendMessage);
}

void Heavy_ChaffVerb::cBinop_xmjksoHB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DWk1wEMg_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_th3G4Otl, 0, m, &sTabread_th3G4Otl_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xcXWCvPO_sendMessage);
}

void Heavy_ChaffVerb::cSystem_Xlu6fqKp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_upqOD3jx, HV_BINOP_SUBTRACT, 1, m, &cBinop_upqOD3jx_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_FLt63fKl, 2, m, &cDelay_FLt63fKl_sendMessage);
}

void Heavy_ChaffVerb::cMsg_JJr6wQEc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Xlu6fqKp_sendMessage);
}

void Heavy_ChaffVerb::cMsg_DWk1wEMg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_BeLuy1it, 0, m, &cDelay_BeLuy1it_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_FLt63fKl, 0, m, &cDelay_FLt63fKl_sendMessage);
}

void Heavy_ChaffVerb::cMsg_mDQE0neO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_qSb7oLea, HV_BINOP_MAX, 1, m, &cBinop_qSb7oLea_sendMessage);
}

void Heavy_ChaffVerb::cBinop_qSb7oLea_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xmjksoHB, HV_BINOP_SUBTRACT, 1, m, &cBinop_xmjksoHB_sendMessage);
}

void Heavy_ChaffVerb::cCast_xcXWCvPO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_BeLuy1it, 0, m, &cDelay_BeLuy1it_sendMessage);
}

void Heavy_ChaffVerb::cBinop_DJ7SZ9l0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_BeLuy1it, 2, m, &cDelay_BeLuy1it_sendMessage);
}

void Heavy_ChaffVerb::cBinop_upqOD3jx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_DJ7SZ9l0_sendMessage);
}

void Heavy_ChaffVerb::cCast_n3kNHbC2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_duAmrU2D, 0, m, &cVar_duAmrU2D_sendMessage);
  cMsg_N4z46cdl_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_VA4Dpeln, 0, m, &cTabhead_VA4Dpeln_sendMessage);
}

void Heavy_ChaffVerb::cTabhead_XqHlMAIZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IVsbH4SK, HV_BINOP_SUBTRACT, 0, m, &cBinop_IVsbH4SK_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Jc3YVD6l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_MpHgxg5N_sendMessage);
}

void Heavy_ChaffVerb::cSystem_MpHgxg5N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_WdQdK43f_sendMessage);
}

void Heavy_ChaffVerb::cVar_UQx5Ua7V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ghdo8ENq_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_AQVZZgml_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_AQVZZgml, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_aAaNTnw9, 0, m, &cDelay_aAaNTnw9_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_AE4mA9Hx, 0, m, &sTabread_AE4mA9Hx_sendMessage);
}

void Heavy_ChaffVerb::cDelay_aAaNTnw9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_aAaNTnw9, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_AE4mA9Hx, 0, m, &sTabread_AE4mA9Hx_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_aAaNTnw9, 0, m, &cDelay_aAaNTnw9_sendMessage);
}

void Heavy_ChaffVerb::sTabread_AE4mA9Hx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_5XBWd3sJ, HV_BINOP_SUBTRACT, 0, m, &cBinop_5XBWd3sJ_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_90swmuyA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3IH8BjUv, HV_BINOP_MAX, 0, m, &cBinop_3IH8BjUv_sendMessage);
}

void Heavy_ChaffVerb::cBinop_WdQdK43f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_90swmuyA, HV_BINOP_MULTIPLY, 0, m, &cBinop_90swmuyA_sendMessage);
}

void Heavy_ChaffVerb::cBinop_IVsbH4SK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_noBAFEzh_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_AE4mA9Hx, 0, m, &sTabread_AE4mA9Hx_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9lXmPfhl_sendMessage);
}

void Heavy_ChaffVerb::cSystem_pRpBW1tG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5XBWd3sJ, HV_BINOP_SUBTRACT, 1, m, &cBinop_5XBWd3sJ_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_aAaNTnw9, 2, m, &cDelay_aAaNTnw9_sendMessage);
}

void Heavy_ChaffVerb::cMsg_ghdo8ENq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_pRpBW1tG_sendMessage);
}

void Heavy_ChaffVerb::cMsg_noBAFEzh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_AQVZZgml, 0, m, &cDelay_AQVZZgml_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_aAaNTnw9, 0, m, &cDelay_aAaNTnw9_sendMessage);
}

void Heavy_ChaffVerb::cMsg_309yVvD4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_3IH8BjUv, HV_BINOP_MAX, 1, m, &cBinop_3IH8BjUv_sendMessage);
}

void Heavy_ChaffVerb::cBinop_3IH8BjUv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IVsbH4SK, HV_BINOP_SUBTRACT, 1, m, &cBinop_IVsbH4SK_sendMessage);
}

void Heavy_ChaffVerb::cCast_9lXmPfhl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_AQVZZgml, 0, m, &cDelay_AQVZZgml_sendMessage);
}

void Heavy_ChaffVerb::cBinop_9IQyeoLr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_AQVZZgml, 2, m, &cDelay_AQVZZgml_sendMessage);
}

void Heavy_ChaffVerb::cBinop_5XBWd3sJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_9IQyeoLr_sendMessage);
}

void Heavy_ChaffVerb::cCast_ATQZ2mft_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_UQx5Ua7V, 0, m, &cVar_UQx5Ua7V_sendMessage);
  cMsg_Jc3YVD6l_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_XqHlMAIZ, 0, m, &cTabhead_XqHlMAIZ_sendMessage);
}

void Heavy_ChaffVerb::cTabhead_UAq06X24_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_StfOboQf, HV_BINOP_SUBTRACT, 0, m, &cBinop_StfOboQf_sendMessage);
}

void Heavy_ChaffVerb::cMsg_4BG8WR8j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_oRl8L6JU_sendMessage);
}

void Heavy_ChaffVerb::cSystem_oRl8L6JU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_9ZeZi6JC_sendMessage);
}

void Heavy_ChaffVerb::cVar_8J0IaKxO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VIlb0SWI_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_SMvEgPUF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_SMvEgPUF, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_KPxlbWXO, 0, m, &cDelay_KPxlbWXO_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_X6xTsZnq, 0, m, &sTabread_X6xTsZnq_sendMessage);
}

void Heavy_ChaffVerb::cDelay_KPxlbWXO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_KPxlbWXO, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_X6xTsZnq, 0, m, &sTabread_X6xTsZnq_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_KPxlbWXO, 0, m, &cDelay_KPxlbWXO_sendMessage);
}

void Heavy_ChaffVerb::sTabread_X6xTsZnq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_x9fnkLkb, HV_BINOP_SUBTRACT, 0, m, &cBinop_x9fnkLkb_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_XT5uGTEk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MP4FfcKz, HV_BINOP_MAX, 0, m, &cBinop_MP4FfcKz_sendMessage);
}

void Heavy_ChaffVerb::cBinop_9ZeZi6JC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XT5uGTEk, HV_BINOP_MULTIPLY, 0, m, &cBinop_XT5uGTEk_sendMessage);
}

void Heavy_ChaffVerb::cBinop_StfOboQf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_D6Wrei83_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_X6xTsZnq, 0, m, &sTabread_X6xTsZnq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vTnFUhfO_sendMessage);
}

void Heavy_ChaffVerb::cSystem_A7I64GsP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_x9fnkLkb, HV_BINOP_SUBTRACT, 1, m, &cBinop_x9fnkLkb_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_KPxlbWXO, 2, m, &cDelay_KPxlbWXO_sendMessage);
}

void Heavy_ChaffVerb::cMsg_VIlb0SWI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_A7I64GsP_sendMessage);
}

void Heavy_ChaffVerb::cMsg_D6Wrei83_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_SMvEgPUF, 0, m, &cDelay_SMvEgPUF_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_KPxlbWXO, 0, m, &cDelay_KPxlbWXO_sendMessage);
}

void Heavy_ChaffVerb::cMsg_3QmcAzeL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_MP4FfcKz, HV_BINOP_MAX, 1, m, &cBinop_MP4FfcKz_sendMessage);
}

void Heavy_ChaffVerb::cBinop_MP4FfcKz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_StfOboQf, HV_BINOP_SUBTRACT, 1, m, &cBinop_StfOboQf_sendMessage);
}

void Heavy_ChaffVerb::cCast_vTnFUhfO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_SMvEgPUF, 0, m, &cDelay_SMvEgPUF_sendMessage);
}

void Heavy_ChaffVerb::cBinop_F9JJxI3T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_SMvEgPUF, 2, m, &cDelay_SMvEgPUF_sendMessage);
}

void Heavy_ChaffVerb::cBinop_x9fnkLkb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_F9JJxI3T_sendMessage);
}

void Heavy_ChaffVerb::cCast_oeSsWBTt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_8J0IaKxO, 0, m, &cVar_8J0IaKxO_sendMessage);
  cMsg_4BG8WR8j_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_UAq06X24, 0, m, &cTabhead_UAq06X24_sendMessage);
}

void Heavy_ChaffVerb::cMsg_6kPqJ1hx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_uQsSKHr1_sendMessage);
}

void Heavy_ChaffVerb::cSystem_uQsSKHr1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_QnxkvObL_sendMessage);
}

void Heavy_ChaffVerb::cDelay_4kORenPA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_4kORenPA, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ytjFawbk, 0, m, &cDelay_ytjFawbk_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_4kORenPA, 0, m, &cDelay_4kORenPA_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_MMvhf21d, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_ytjFawbk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ytjFawbk, m);
  cMsg_tqTlZJw8_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_AXOUftUU_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_SaB8uGuB_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_1CZnNarz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5OzUP8C3_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_7kBrnt8n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DLTply1b_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_4kORenPA, 2, m, &cDelay_4kORenPA_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Z9muUZ3c_sendMessage);
}

void Heavy_ChaffVerb::cMsg_5OzUP8C3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_7kBrnt8n, 0, m, &hTable_7kBrnt8n_sendMessage);
}

void Heavy_ChaffVerb::cBinop_QnxkvObL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 58.6435f, 0, m, &cBinop_1CZnNarz_sendMessage);
}

void Heavy_ChaffVerb::cMsg_tqTlZJw8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_7kBrnt8n, 0, m, &hTable_7kBrnt8n_sendMessage);
}

void Heavy_ChaffVerb::cCast_Z9muUZ3c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_4kORenPA, 0, m, &cDelay_4kORenPA_sendMessage);
}

void Heavy_ChaffVerb::cMsg_DLTply1b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_ytjFawbk, 2, m, &cDelay_ytjFawbk_sendMessage);
}

void Heavy_ChaffVerb::cMsg_SaB8uGuB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_MMvhf21d, 1, m, NULL);
}

void Heavy_ChaffVerb::cMsg_sKm1mgSw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_D7G7X6pT_sendMessage);
}

void Heavy_ChaffVerb::cSystem_D7G7X6pT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_6vGREai6_sendMessage);
}

void Heavy_ChaffVerb::cDelay_C4wXfBeJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_C4wXfBeJ, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Xlv7V6aR, 0, m, &cDelay_Xlv7V6aR_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_C4wXfBeJ, 0, m, &cDelay_C4wXfBeJ_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_YERfVzFy, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_Xlv7V6aR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Xlv7V6aR, m);
  cMsg_JBcSLajx_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_HpW0hPN8_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_SlGBNbB9_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_wbptSjuN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_a9KDEaYj_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_1xUNdlcx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_aloHAn46_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_C4wXfBeJ, 2, m, &cDelay_C4wXfBeJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PVJjUAS1_sendMessage);
}

void Heavy_ChaffVerb::cMsg_a9KDEaYj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_1xUNdlcx, 0, m, &hTable_1xUNdlcx_sendMessage);
}

void Heavy_ChaffVerb::cBinop_6vGREai6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 69.4325f, 0, m, &cBinop_wbptSjuN_sendMessage);
}

void Heavy_ChaffVerb::cMsg_JBcSLajx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_1xUNdlcx, 0, m, &hTable_1xUNdlcx_sendMessage);
}

void Heavy_ChaffVerb::cCast_PVJjUAS1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_C4wXfBeJ, 0, m, &cDelay_C4wXfBeJ_sendMessage);
}

void Heavy_ChaffVerb::cMsg_aloHAn46_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_Xlv7V6aR, 2, m, &cDelay_Xlv7V6aR_sendMessage);
}

void Heavy_ChaffVerb::cMsg_SlGBNbB9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_YERfVzFy, 1, m, NULL);
}

void Heavy_ChaffVerb::cMsg_Gl43MpP2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_lrfC8gu4_sendMessage);
}

void Heavy_ChaffVerb::cSystem_lrfC8gu4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_p4yT5hXz_sendMessage);
}

void Heavy_ChaffVerb::cDelay_hhAVud4i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_hhAVud4i, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_OJotLSZG, 0, m, &cDelay_OJotLSZG_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_hhAVud4i, 0, m, &cDelay_hhAVud4i_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_O51OxZpp, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_OJotLSZG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_OJotLSZG, m);
  cMsg_HTVB73gb_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_RCgoxEuJ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_cD6eiIWZ_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_C3Fa0nna_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Nhbrn1Ie_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_nm3JUNrt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wVGj9gWN_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_hhAVud4i, 2, m, &cDelay_hhAVud4i_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HhOE115Z_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Nhbrn1Ie_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_nm3JUNrt, 0, m, &hTable_nm3JUNrt_sendMessage);
}

void Heavy_ChaffVerb::cBinop_p4yT5hXz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 74.5234f, 0, m, &cBinop_C3Fa0nna_sendMessage);
}

void Heavy_ChaffVerb::cMsg_HTVB73gb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_nm3JUNrt, 0, m, &hTable_nm3JUNrt_sendMessage);
}

void Heavy_ChaffVerb::cCast_HhOE115Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_hhAVud4i, 0, m, &cDelay_hhAVud4i_sendMessage);
}

void Heavy_ChaffVerb::cMsg_wVGj9gWN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_OJotLSZG, 2, m, &cDelay_OJotLSZG_sendMessage);
}

void Heavy_ChaffVerb::cMsg_cD6eiIWZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_O51OxZpp, 1, m, NULL);
}

void Heavy_ChaffVerb::cMsg_ArNEA6sz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_tNofymvL_sendMessage);
}

void Heavy_ChaffVerb::cSystem_tNofymvL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_doanKiCB_sendMessage);
}

void Heavy_ChaffVerb::cDelay_NepzIRVJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_NepzIRVJ, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_PGkuQft8, 0, m, &cDelay_PGkuQft8_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_NepzIRVJ, 0, m, &cDelay_NepzIRVJ_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_Lw4JCPC8, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_PGkuQft8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_PGkuQft8, m);
  cMsg_ywCNvpql_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_xqz1wywP_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_qsGH07Gs_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_vtBf2eop_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6vRfkiLy_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_rsPSl4Tm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_aGqYcOb9_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_NepzIRVJ, 2, m, &cDelay_NepzIRVJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xrvixtiR_sendMessage);
}

void Heavy_ChaffVerb::cMsg_6vRfkiLy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_rsPSl4Tm, 0, m, &hTable_rsPSl4Tm_sendMessage);
}

void Heavy_ChaffVerb::cBinop_doanKiCB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 86.1244f, 0, m, &cBinop_vtBf2eop_sendMessage);
}

void Heavy_ChaffVerb::cMsg_ywCNvpql_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_rsPSl4Tm, 0, m, &hTable_rsPSl4Tm_sendMessage);
}

void Heavy_ChaffVerb::cCast_xrvixtiR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_NepzIRVJ, 0, m, &cDelay_NepzIRVJ_sendMessage);
}

void Heavy_ChaffVerb::cMsg_aGqYcOb9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_PGkuQft8, 2, m, &cDelay_PGkuQft8_sendMessage);
}

void Heavy_ChaffVerb::cMsg_qsGH07Gs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_Lw4JCPC8, 1, m, NULL);
}

void Heavy_ChaffVerb::cPack_wNA7kvlC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sLine_onMessage(_c, &Context(_c)->sLine_J29RWejQ, 0, m, NULL);
}

void Heavy_ChaffVerb::cPack_JBiKGciB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sLine_onMessage(_c, &Context(_c)->sLine_ynbCPTOR, 0, m, NULL);
}

void Heavy_ChaffVerb::cBinop_9VaCmh0x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_kASqpcXb_sendMessage);
}

void Heavy_ChaffVerb::cBinop_kASqpcXb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 200.0f, 0, m, &cBinop_uB68DMSz_sendMessage);
}

void Heavy_ChaffVerb::cVar_7ggzn5Xa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_K7l76Jf2, HV_BINOP_MULTIPLY, 0, m, &cBinop_K7l76Jf2_sendMessage);
}

void Heavy_ChaffVerb::cMsg_pZycvGpy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_WziA1f6m_sendMessage);
}

void Heavy_ChaffVerb::cSystem_WziA1f6m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_i7oSQtEE_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_K7l76Jf2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_T4FeJFuM_sendMessage);
}

void Heavy_ChaffVerb::cBinop_nQLueF4y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_K7l76Jf2, HV_BINOP_MULTIPLY, 1, m, &cBinop_K7l76Jf2_sendMessage);
}

void Heavy_ChaffVerb::cMsg_i7oSQtEE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_nQLueF4y_sendMessage);
}

void Heavy_ChaffVerb::cBinop_T4FeJFuM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_y8xS2Sxd_sendMessage);
}

void Heavy_ChaffVerb::cBinop_y8xS2Sxd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_mCi6LIx7_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_LkrWIftb, m);
}

void Heavy_ChaffVerb::cBinop_mCi6LIx7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_CERnyAlN, m);
}

void Heavy_ChaffVerb::cVar_GeRuZH7Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.125f, 0, m, &cBinop_G3XpwHNJ_sendMessage);
}

void Heavy_ChaffVerb::cVar_c6zEK3um_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_9VaCmh0x_sendMessage);
}

void Heavy_ChaffVerb::cVar_mwrwjSDQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN_EQL, 1.0f, 0, m, &cBinop_bWK8nizr_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_PcnMCFSg, 0, m, &cIf_PcnMCFSg_sendMessage);
}

void Heavy_ChaffVerb::cVar_rEr8UQZ4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_kjQi6ijo_sendMessage);
}

void Heavy_ChaffVerb::cIf_PcnMCFSg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_UTNVBYnF_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_XToIk3cI, 0, m, &cVar_XToIk3cI_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_bWK8nizr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_PcnMCFSg, 1, m, &cIf_PcnMCFSg_sendMessage);
}

void Heavy_ChaffVerb::cBinop_kjQi6ijo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_jRtoRJ1f_sendMessage);
}

void Heavy_ChaffVerb::cBinop_jRtoRJ1f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xH7yhFLM, 0, m, &cVar_xH7yhFLM_sendMessage);
}

void Heavy_ChaffVerb::cMsg_7ThxcDek_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_hIB7FzNR_sendMessage);
}

void Heavy_ChaffVerb::cSystem_hIB7FzNR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_KBeSI2L8_sendMessage);
}

void Heavy_ChaffVerb::cDelay_ahxUkapM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ahxUkapM, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_sye1z9Wd, 0, m, &cDelay_sye1z9Wd_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ahxUkapM, 0, m, &cDelay_ahxUkapM_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_SBUXmKRO, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_sye1z9Wd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_sye1z9Wd, m);
  cMsg_nsW5ew2c_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_I3twc1nT_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_vaUUCDwG_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_OEahZ9AP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_A1eCcjBN_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_vXtBaWoj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CBOuE36E_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ahxUkapM, 2, m, &cDelay_ahxUkapM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GkN1GdSo_sendMessage);
}

void Heavy_ChaffVerb::cMsg_A1eCcjBN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_vXtBaWoj, 0, m, &hTable_vXtBaWoj_sendMessage);
}

void Heavy_ChaffVerb::cBinop_KBeSI2L8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 43.5337f, 0, m, &cBinop_OEahZ9AP_sendMessage);
}

void Heavy_ChaffVerb::cMsg_nsW5ew2c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_vXtBaWoj, 0, m, &hTable_vXtBaWoj_sendMessage);
}

void Heavy_ChaffVerb::cCast_GkN1GdSo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ahxUkapM, 0, m, &cDelay_ahxUkapM_sendMessage);
}

void Heavy_ChaffVerb::cMsg_CBOuE36E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_sye1z9Wd, 2, m, &cDelay_sye1z9Wd_sendMessage);
}

void Heavy_ChaffVerb::cMsg_vaUUCDwG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_SBUXmKRO, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_x2nIKaC8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PjHLNWo3, HV_BINOP_SUBTRACT, 0, m, &cBinop_PjHLNWo3_sendMessage);
}

void Heavy_ChaffVerb::cMsg_P1dpeHgH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_EJyTaO5s_sendMessage);
}

void Heavy_ChaffVerb::cSystem_EJyTaO5s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_UgbVPzbD_sendMessage);
}

void Heavy_ChaffVerb::cVar_jJcbCOKM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HxYalM7K_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_ZS0nhyOr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ZS0nhyOr, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_lkFsyYNC, 0, m, &cDelay_lkFsyYNC_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_XTMScFCN, 0, m, &sTabread_XTMScFCN_sendMessage);
}

void Heavy_ChaffVerb::cDelay_lkFsyYNC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_lkFsyYNC, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_XTMScFCN, 0, m, &sTabread_XTMScFCN_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_lkFsyYNC, 0, m, &cDelay_lkFsyYNC_sendMessage);
}

void Heavy_ChaffVerb::sTabread_XTMScFCN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_m2uQ3ZU7, HV_BINOP_SUBTRACT, 0, m, &cBinop_m2uQ3ZU7_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_pICtUoFf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_y4dljvy2, HV_BINOP_MAX, 0, m, &cBinop_y4dljvy2_sendMessage);
}

void Heavy_ChaffVerb::cBinop_UgbVPzbD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pICtUoFf, HV_BINOP_MULTIPLY, 0, m, &cBinop_pICtUoFf_sendMessage);
}

void Heavy_ChaffVerb::cBinop_PjHLNWo3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VU2lIrUm_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_XTMScFCN, 0, m, &sTabread_XTMScFCN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_W6qoaHMd_sendMessage);
}

void Heavy_ChaffVerb::cSystem_JREmjov9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_m2uQ3ZU7, HV_BINOP_SUBTRACT, 1, m, &cBinop_m2uQ3ZU7_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_lkFsyYNC, 2, m, &cDelay_lkFsyYNC_sendMessage);
}

void Heavy_ChaffVerb::cMsg_HxYalM7K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_JREmjov9_sendMessage);
}

void Heavy_ChaffVerb::cMsg_VU2lIrUm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_ZS0nhyOr, 0, m, &cDelay_ZS0nhyOr_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_lkFsyYNC, 0, m, &cDelay_lkFsyYNC_sendMessage);
}

void Heavy_ChaffVerb::cMsg_TPV2IYLr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_y4dljvy2, HV_BINOP_MAX, 1, m, &cBinop_y4dljvy2_sendMessage);
}

void Heavy_ChaffVerb::cBinop_y4dljvy2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PjHLNWo3, HV_BINOP_SUBTRACT, 1, m, &cBinop_PjHLNWo3_sendMessage);
}

void Heavy_ChaffVerb::cCast_W6qoaHMd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ZS0nhyOr, 0, m, &cDelay_ZS0nhyOr_sendMessage);
}

void Heavy_ChaffVerb::cBinop_vJNiDuZI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ZS0nhyOr, 2, m, &cDelay_ZS0nhyOr_sendMessage);
}

void Heavy_ChaffVerb::cBinop_m2uQ3ZU7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_vJNiDuZI_sendMessage);
}

void Heavy_ChaffVerb::cCast_bJkKG9XV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_jJcbCOKM, 0, m, &cVar_jJcbCOKM_sendMessage);
  cMsg_P1dpeHgH_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_x2nIKaC8, 0, m, &cTabhead_x2nIKaC8_sendMessage);
}

void Heavy_ChaffVerb::cMsg_pcGEEDB2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_JIUT4wvl_sendMessage);
}

void Heavy_ChaffVerb::cSystem_JIUT4wvl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_ZflEpHtB_sendMessage);
}

void Heavy_ChaffVerb::cDelay_A22Y5jMS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_A22Y5jMS, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_XVwWty9X, 0, m, &cDelay_XVwWty9X_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_A22Y5jMS, 0, m, &cDelay_A22Y5jMS_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_WbBLYnnu, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_XVwWty9X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_XVwWty9X, m);
  cMsg_34C9l6jh_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_aZsY2cQ6_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_Zm1X8unb_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_TyeqGB07_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_oX5E1uR1_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_uE3Ot1l8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9URvEttJ_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_A22Y5jMS, 2, m, &cDelay_A22Y5jMS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sIuQc7yM_sendMessage);
}

void Heavy_ChaffVerb::cMsg_oX5E1uR1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_uE3Ot1l8, 0, m, &hTable_uE3Ot1l8_sendMessage);
}

void Heavy_ChaffVerb::cBinop_ZflEpHtB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 25.796f, 0, m, &cBinop_TyeqGB07_sendMessage);
}

void Heavy_ChaffVerb::cMsg_34C9l6jh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_uE3Ot1l8, 0, m, &hTable_uE3Ot1l8_sendMessage);
}

void Heavy_ChaffVerb::cCast_sIuQc7yM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_A22Y5jMS, 0, m, &cDelay_A22Y5jMS_sendMessage);
}

void Heavy_ChaffVerb::cMsg_9URvEttJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_XVwWty9X, 2, m, &cDelay_XVwWty9X_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Zm1X8unb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_WbBLYnnu, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_6Vy8nZVe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aja27uYt, HV_BINOP_SUBTRACT, 0, m, &cBinop_aja27uYt_sendMessage);
}

void Heavy_ChaffVerb::cMsg_wHRToKRL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_4EIpLCeq_sendMessage);
}

void Heavy_ChaffVerb::cSystem_4EIpLCeq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_jGV7Kqw1_sendMessage);
}

void Heavy_ChaffVerb::cVar_Mf7QKgUx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sHVYFihx_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_KAvz7USG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_KAvz7USG, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_3VaqIJDR, 0, m, &cDelay_3VaqIJDR_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_M0VW0xTw, 0, m, &sTabread_M0VW0xTw_sendMessage);
}

void Heavy_ChaffVerb::cDelay_3VaqIJDR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_3VaqIJDR, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_M0VW0xTw, 0, m, &sTabread_M0VW0xTw_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_3VaqIJDR, 0, m, &cDelay_3VaqIJDR_sendMessage);
}

void Heavy_ChaffVerb::sTabread_M0VW0xTw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_nDfllkRe, HV_BINOP_SUBTRACT, 0, m, &cBinop_nDfllkRe_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_YNxW4vml_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oX2lntrp, HV_BINOP_MAX, 0, m, &cBinop_oX2lntrp_sendMessage);
}

void Heavy_ChaffVerb::cBinop_jGV7Kqw1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YNxW4vml, HV_BINOP_MULTIPLY, 0, m, &cBinop_YNxW4vml_sendMessage);
}

void Heavy_ChaffVerb::cBinop_aja27uYt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_q7jwYmZV_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_M0VW0xTw, 0, m, &sTabread_M0VW0xTw_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9PuVTALd_sendMessage);
}

void Heavy_ChaffVerb::cSystem_sCV1wmNg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nDfllkRe, HV_BINOP_SUBTRACT, 1, m, &cBinop_nDfllkRe_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_3VaqIJDR, 2, m, &cDelay_3VaqIJDR_sendMessage);
}

void Heavy_ChaffVerb::cMsg_sHVYFihx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_sCV1wmNg_sendMessage);
}

void Heavy_ChaffVerb::cMsg_q7jwYmZV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_KAvz7USG, 0, m, &cDelay_KAvz7USG_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_3VaqIJDR, 0, m, &cDelay_3VaqIJDR_sendMessage);
}

void Heavy_ChaffVerb::cMsg_wGVAWwuB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_oX2lntrp, HV_BINOP_MAX, 1, m, &cBinop_oX2lntrp_sendMessage);
}

void Heavy_ChaffVerb::cBinop_oX2lntrp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aja27uYt, HV_BINOP_SUBTRACT, 1, m, &cBinop_aja27uYt_sendMessage);
}

void Heavy_ChaffVerb::cCast_9PuVTALd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_KAvz7USG, 0, m, &cDelay_KAvz7USG_sendMessage);
}

void Heavy_ChaffVerb::cBinop_brcAl4oy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_KAvz7USG, 2, m, &cDelay_KAvz7USG_sendMessage);
}

void Heavy_ChaffVerb::cBinop_nDfllkRe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_brcAl4oy_sendMessage);
}

void Heavy_ChaffVerb::cCast_V8Cd1Dsd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Mf7QKgUx, 0, m, &cVar_Mf7QKgUx_sendMessage);
  cMsg_wHRToKRL_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_6Vy8nZVe, 0, m, &cTabhead_6Vy8nZVe_sendMessage);
}

void Heavy_ChaffVerb::cMsg_N6jr4Ckb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_nQscFIOo_sendMessage);
}

void Heavy_ChaffVerb::cSystem_nQscFIOo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_OXHGQKTG_sendMessage);
}

void Heavy_ChaffVerb::cDelay_j4ukQrjq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_j4ukQrjq, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_fNgTCjFU, 0, m, &cDelay_fNgTCjFU_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_j4ukQrjq, 0, m, &cDelay_j4ukQrjq_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_GWSzT4Ha, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_fNgTCjFU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_fNgTCjFU, m);
  cMsg_9um9bxSH_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_0sWt2Fyu_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_V8kUgIrs_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_LiZWSINr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mIxLuNMg_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_DrAvi7Sc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DIj5nGMl_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_j4ukQrjq, 2, m, &cDelay_j4ukQrjq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HevBg66p_sendMessage);
}

void Heavy_ChaffVerb::cMsg_mIxLuNMg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_DrAvi7Sc, 0, m, &hTable_DrAvi7Sc_sendMessage);
}

void Heavy_ChaffVerb::cBinop_OXHGQKTG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 19.392f, 0, m, &cBinop_LiZWSINr_sendMessage);
}

void Heavy_ChaffVerb::cMsg_9um9bxSH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_DrAvi7Sc, 0, m, &hTable_DrAvi7Sc_sendMessage);
}

void Heavy_ChaffVerb::cCast_HevBg66p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_j4ukQrjq, 0, m, &cDelay_j4ukQrjq_sendMessage);
}

void Heavy_ChaffVerb::cMsg_DIj5nGMl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_fNgTCjFU, 2, m, &cDelay_fNgTCjFU_sendMessage);
}

void Heavy_ChaffVerb::cMsg_V8kUgIrs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_GWSzT4Ha, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_zyHrbWra_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_b8fugLPa, HV_BINOP_SUBTRACT, 0, m, &cBinop_b8fugLPa_sendMessage);
}

void Heavy_ChaffVerb::cMsg_CB0huZq9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_MG6nhfMI_sendMessage);
}

void Heavy_ChaffVerb::cSystem_MG6nhfMI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_kWDrr42H_sendMessage);
}

void Heavy_ChaffVerb::cVar_bgjx0mgk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zgcvKPkH_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_UIj6a4jk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_UIj6a4jk, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ZbOa7VDi, 0, m, &cDelay_ZbOa7VDi_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_eJqQW8jk, 0, m, &sTabread_eJqQW8jk_sendMessage);
}

void Heavy_ChaffVerb::cDelay_ZbOa7VDi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ZbOa7VDi, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_eJqQW8jk, 0, m, &sTabread_eJqQW8jk_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ZbOa7VDi, 0, m, &cDelay_ZbOa7VDi_sendMessage);
}

void Heavy_ChaffVerb::sTabread_eJqQW8jk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_roQ4Qwio, HV_BINOP_SUBTRACT, 0, m, &cBinop_roQ4Qwio_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_vwkI5CYg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QYzZGBBV, HV_BINOP_MAX, 0, m, &cBinop_QYzZGBBV_sendMessage);
}

void Heavy_ChaffVerb::cBinop_kWDrr42H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vwkI5CYg, HV_BINOP_MULTIPLY, 0, m, &cBinop_vwkI5CYg_sendMessage);
}

void Heavy_ChaffVerb::cBinop_b8fugLPa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_71cZPPjV_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_eJqQW8jk, 0, m, &sTabread_eJqQW8jk_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_htomWwgW_sendMessage);
}

void Heavy_ChaffVerb::cSystem_DxnHERYb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_roQ4Qwio, HV_BINOP_SUBTRACT, 1, m, &cBinop_roQ4Qwio_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ZbOa7VDi, 2, m, &cDelay_ZbOa7VDi_sendMessage);
}

void Heavy_ChaffVerb::cMsg_zgcvKPkH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_DxnHERYb_sendMessage);
}

void Heavy_ChaffVerb::cMsg_71cZPPjV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_UIj6a4jk, 0, m, &cDelay_UIj6a4jk_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ZbOa7VDi, 0, m, &cDelay_ZbOa7VDi_sendMessage);
}

void Heavy_ChaffVerb::cMsg_8PaZS3po_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_QYzZGBBV, HV_BINOP_MAX, 1, m, &cBinop_QYzZGBBV_sendMessage);
}

void Heavy_ChaffVerb::cBinop_QYzZGBBV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_b8fugLPa, HV_BINOP_SUBTRACT, 1, m, &cBinop_b8fugLPa_sendMessage);
}

void Heavy_ChaffVerb::cCast_htomWwgW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_UIj6a4jk, 0, m, &cDelay_UIj6a4jk_sendMessage);
}

void Heavy_ChaffVerb::cBinop_0csjVuHV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_UIj6a4jk, 2, m, &cDelay_UIj6a4jk_sendMessage);
}

void Heavy_ChaffVerb::cBinop_roQ4Qwio_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_0csjVuHV_sendMessage);
}

void Heavy_ChaffVerb::cCast_C0Mm96OB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_bgjx0mgk, 0, m, &cVar_bgjx0mgk_sendMessage);
  cMsg_CB0huZq9_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_zyHrbWra, 0, m, &cTabhead_zyHrbWra_sendMessage);
}

void Heavy_ChaffVerb::cMsg_MBwZye4N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_IWx0kb68_sendMessage);
}

void Heavy_ChaffVerb::cSystem_IWx0kb68_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_rmgAIBEl_sendMessage);
}

void Heavy_ChaffVerb::cDelay_Px84b0no_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Px84b0no, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_9tjciN2j, 0, m, &cDelay_9tjciN2j_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Px84b0no, 0, m, &cDelay_Px84b0no_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_F6KBU0Qs, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_9tjciN2j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_9tjciN2j, m);
  cMsg_ivGpXkV5_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_5yDLaby5_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_UqSQaLGU_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_OimAC3rd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1zrkWvWK_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_2WS3L7y9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lbStRgtE_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Px84b0no, 2, m, &cDelay_Px84b0no_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_i9thlQ5V_sendMessage);
}

void Heavy_ChaffVerb::cMsg_1zrkWvWK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_2WS3L7y9, 0, m, &hTable_2WS3L7y9_sendMessage);
}

void Heavy_ChaffVerb::cBinop_rmgAIBEl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 16.364f, 0, m, &cBinop_OimAC3rd_sendMessage);
}

void Heavy_ChaffVerb::cMsg_ivGpXkV5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_2WS3L7y9, 0, m, &hTable_2WS3L7y9_sendMessage);
}

void Heavy_ChaffVerb::cCast_i9thlQ5V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Px84b0no, 0, m, &cDelay_Px84b0no_sendMessage);
}

void Heavy_ChaffVerb::cMsg_lbStRgtE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_9tjciN2j, 2, m, &cDelay_9tjciN2j_sendMessage);
}

void Heavy_ChaffVerb::cMsg_UqSQaLGU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_F6KBU0Qs, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_20BNRcIp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4i9pubG8, HV_BINOP_SUBTRACT, 0, m, &cBinop_4i9pubG8_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Eb64wrwn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_NaGw7Mqc_sendMessage);
}

void Heavy_ChaffVerb::cSystem_NaGw7Mqc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_udXl7t7m_sendMessage);
}

void Heavy_ChaffVerb::cVar_zzQBv86M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NnUuwxEW_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_vCv9eIP6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_vCv9eIP6, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_bP9ZfhRf, 0, m, &cDelay_bP9ZfhRf_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_roh7vvPE, 0, m, &sTabread_roh7vvPE_sendMessage);
}

void Heavy_ChaffVerb::cDelay_bP9ZfhRf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_bP9ZfhRf, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_roh7vvPE, 0, m, &sTabread_roh7vvPE_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_bP9ZfhRf, 0, m, &cDelay_bP9ZfhRf_sendMessage);
}

void Heavy_ChaffVerb::sTabread_roh7vvPE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_llnytlO3, HV_BINOP_SUBTRACT, 0, m, &cBinop_llnytlO3_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_SnEBMlYc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tqxpDGic, HV_BINOP_MAX, 0, m, &cBinop_tqxpDGic_sendMessage);
}

void Heavy_ChaffVerb::cBinop_udXl7t7m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SnEBMlYc, HV_BINOP_MULTIPLY, 0, m, &cBinop_SnEBMlYc_sendMessage);
}

void Heavy_ChaffVerb::cBinop_4i9pubG8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iCLp5daO_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_roh7vvPE, 0, m, &sTabread_roh7vvPE_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jFFPQND0_sendMessage);
}

void Heavy_ChaffVerb::cSystem_FIh8FRZM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_llnytlO3, HV_BINOP_SUBTRACT, 1, m, &cBinop_llnytlO3_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_bP9ZfhRf, 2, m, &cDelay_bP9ZfhRf_sendMessage);
}

void Heavy_ChaffVerb::cMsg_NnUuwxEW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_FIh8FRZM_sendMessage);
}

void Heavy_ChaffVerb::cMsg_iCLp5daO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_vCv9eIP6, 0, m, &cDelay_vCv9eIP6_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_bP9ZfhRf, 0, m, &cDelay_bP9ZfhRf_sendMessage);
}

void Heavy_ChaffVerb::cMsg_fcKyUGis_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_tqxpDGic, HV_BINOP_MAX, 1, m, &cBinop_tqxpDGic_sendMessage);
}

void Heavy_ChaffVerb::cBinop_tqxpDGic_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4i9pubG8, HV_BINOP_SUBTRACT, 1, m, &cBinop_4i9pubG8_sendMessage);
}

void Heavy_ChaffVerb::cCast_jFFPQND0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_vCv9eIP6, 0, m, &cDelay_vCv9eIP6_sendMessage);
}

void Heavy_ChaffVerb::cBinop_fdFTHIZy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_vCv9eIP6, 2, m, &cDelay_vCv9eIP6_sendMessage);
}

void Heavy_ChaffVerb::cBinop_llnytlO3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_fdFTHIZy_sendMessage);
}

void Heavy_ChaffVerb::cCast_1hdpcnRv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_zzQBv86M, 0, m, &cVar_zzQBv86M_sendMessage);
  cMsg_Eb64wrwn_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_20BNRcIp, 0, m, &cTabhead_20BNRcIp_sendMessage);
}

void Heavy_ChaffVerb::cMsg_9WYVuL60_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_A5iejV6I_sendMessage);
}

void Heavy_ChaffVerb::cSystem_A5iejV6I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_4WvVU3D5_sendMessage);
}

void Heavy_ChaffVerb::cDelay_fflkwnoD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_fflkwnoD, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_nRjebdX3, 0, m, &cDelay_nRjebdX3_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_fflkwnoD, 0, m, &cDelay_fflkwnoD_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_OR6AOtRm, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_nRjebdX3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_nRjebdX3, m);
  cMsg_xYXlP7HP_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_JEUll63z_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_DAwCzZvd_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_dsQPZ6o2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fN3PIY3j_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_j7wVbqKq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XG7c11j4_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_fflkwnoD, 2, m, &cDelay_fflkwnoD_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_elhKUarA_sendMessage);
}

void Heavy_ChaffVerb::cMsg_fN3PIY3j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_j7wVbqKq, 0, m, &hTable_j7wVbqKq_sendMessage);
}

void Heavy_ChaffVerb::cBinop_4WvVU3D5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 4.2546f, 0, m, &cBinop_dsQPZ6o2_sendMessage);
}

void Heavy_ChaffVerb::cMsg_xYXlP7HP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_j7wVbqKq, 0, m, &hTable_j7wVbqKq_sendMessage);
}

void Heavy_ChaffVerb::cCast_elhKUarA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_fflkwnoD, 0, m, &cDelay_fflkwnoD_sendMessage);
}

void Heavy_ChaffVerb::cMsg_XG7c11j4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_nRjebdX3, 2, m, &cDelay_nRjebdX3_sendMessage);
}

void Heavy_ChaffVerb::cMsg_DAwCzZvd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_OR6AOtRm, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_ojFAOURY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XojDhFOY, HV_BINOP_SUBTRACT, 0, m, &cBinop_XojDhFOY_sendMessage);
}

void Heavy_ChaffVerb::cMsg_YpElZbo7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_3qzw2uWn_sendMessage);
}

void Heavy_ChaffVerb::cSystem_3qzw2uWn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_s1lLdTT6_sendMessage);
}

void Heavy_ChaffVerb::cVar_ESqy9KLJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_e5noVJUi_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_ISDAUf0Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ISDAUf0Y, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_qoy4b32I, 0, m, &cDelay_qoy4b32I_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_UI1hGaCm, 0, m, &sTabread_UI1hGaCm_sendMessage);
}

void Heavy_ChaffVerb::cDelay_qoy4b32I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_qoy4b32I, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_UI1hGaCm, 0, m, &sTabread_UI1hGaCm_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_qoy4b32I, 0, m, &cDelay_qoy4b32I_sendMessage);
}

void Heavy_ChaffVerb::sTabread_UI1hGaCm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_k7oNpgJL, HV_BINOP_SUBTRACT, 0, m, &cBinop_k7oNpgJL_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_bzMlKF7P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FnOPDHcS, HV_BINOP_MAX, 0, m, &cBinop_FnOPDHcS_sendMessage);
}

void Heavy_ChaffVerb::cBinop_s1lLdTT6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bzMlKF7P, HV_BINOP_MULTIPLY, 0, m, &cBinop_bzMlKF7P_sendMessage);
}

void Heavy_ChaffVerb::cBinop_XojDhFOY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2LXh3dJH_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_UI1hGaCm, 0, m, &sTabread_UI1hGaCm_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zj4ZaxVh_sendMessage);
}

void Heavy_ChaffVerb::cSystem_b9jU9jtw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_k7oNpgJL, HV_BINOP_SUBTRACT, 1, m, &cBinop_k7oNpgJL_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_qoy4b32I, 2, m, &cDelay_qoy4b32I_sendMessage);
}

void Heavy_ChaffVerb::cMsg_e5noVJUi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_b9jU9jtw_sendMessage);
}

void Heavy_ChaffVerb::cMsg_2LXh3dJH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_ISDAUf0Y, 0, m, &cDelay_ISDAUf0Y_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_qoy4b32I, 0, m, &cDelay_qoy4b32I_sendMessage);
}

void Heavy_ChaffVerb::cMsg_A96hIF3Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_FnOPDHcS, HV_BINOP_MAX, 1, m, &cBinop_FnOPDHcS_sendMessage);
}

void Heavy_ChaffVerb::cBinop_FnOPDHcS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XojDhFOY, HV_BINOP_SUBTRACT, 1, m, &cBinop_XojDhFOY_sendMessage);
}

void Heavy_ChaffVerb::cCast_zj4ZaxVh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ISDAUf0Y, 0, m, &cDelay_ISDAUf0Y_sendMessage);
}

void Heavy_ChaffVerb::cBinop_KPLMlns5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ISDAUf0Y, 2, m, &cDelay_ISDAUf0Y_sendMessage);
}

void Heavy_ChaffVerb::cBinop_k7oNpgJL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_KPLMlns5_sendMessage);
}

void Heavy_ChaffVerb::cCast_ewG2OqBM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ESqy9KLJ, 0, m, &cVar_ESqy9KLJ_sendMessage);
  cMsg_YpElZbo7_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_ojFAOURY, 0, m, &cTabhead_ojFAOURY_sendMessage);
}

void Heavy_ChaffVerb::cMsg_ZN9jokWa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_imUxIHVX_sendMessage);
}

void Heavy_ChaffVerb::cSystem_imUxIHVX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_NbkVlCZ0_sendMessage);
}

void Heavy_ChaffVerb::cDelay_MYe6A5UG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_MYe6A5UG, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Cdv7eGzd, 0, m, &cDelay_Cdv7eGzd_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_MYe6A5UG, 0, m, &cDelay_MYe6A5UG_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_jDiXJTXV, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_Cdv7eGzd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Cdv7eGzd, m);
  cMsg_elfAolBq_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_swWgxSCw_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_uKpVpDwv_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_9Ws7xr6D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HSce5Fne_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_R3bW1ryO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Gd1RaJvQ_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_MYe6A5UG, 2, m, &cDelay_MYe6A5UG_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZHu0WLae_sendMessage);
}

void Heavy_ChaffVerb::cMsg_HSce5Fne_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_R3bW1ryO, 0, m, &hTable_R3bW1ryO_sendMessage);
}

void Heavy_ChaffVerb::cBinop_NbkVlCZ0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 7.645f, 0, m, &cBinop_9Ws7xr6D_sendMessage);
}

void Heavy_ChaffVerb::cMsg_elfAolBq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_R3bW1ryO, 0, m, &hTable_R3bW1ryO_sendMessage);
}

void Heavy_ChaffVerb::cCast_ZHu0WLae_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_MYe6A5UG, 0, m, &cDelay_MYe6A5UG_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Gd1RaJvQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_Cdv7eGzd, 2, m, &cDelay_Cdv7eGzd_sendMessage);
}

void Heavy_ChaffVerb::cMsg_uKpVpDwv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_jDiXJTXV, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_3Z4GP1lw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sg5CTzNp, HV_BINOP_SUBTRACT, 0, m, &cBinop_sg5CTzNp_sendMessage);
}

void Heavy_ChaffVerb::cMsg_s43d9apf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_0GMwlXDR_sendMessage);
}

void Heavy_ChaffVerb::cSystem_0GMwlXDR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_j7F6pcSZ_sendMessage);
}

void Heavy_ChaffVerb::cVar_1GhhzQiX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Xuhrtue7_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_H8Gx4Ne0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_H8Gx4Ne0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Kc2Mgbkx, 0, m, &cDelay_Kc2Mgbkx_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_myNO78PS, 0, m, &sTabread_myNO78PS_sendMessage);
}

void Heavy_ChaffVerb::cDelay_Kc2Mgbkx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Kc2Mgbkx, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_myNO78PS, 0, m, &sTabread_myNO78PS_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Kc2Mgbkx, 0, m, &cDelay_Kc2Mgbkx_sendMessage);
}

void Heavy_ChaffVerb::sTabread_myNO78PS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_KOyAKbne, HV_BINOP_SUBTRACT, 0, m, &cBinop_KOyAKbne_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_VBiHMfQ2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OPvv6QhH, HV_BINOP_MAX, 0, m, &cBinop_OPvv6QhH_sendMessage);
}

void Heavy_ChaffVerb::cBinop_j7F6pcSZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VBiHMfQ2, HV_BINOP_MULTIPLY, 0, m, &cBinop_VBiHMfQ2_sendMessage);
}

void Heavy_ChaffVerb::cBinop_sg5CTzNp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ehW6tAKD_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_myNO78PS, 0, m, &sTabread_myNO78PS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RgIXwwCv_sendMessage);
}

void Heavy_ChaffVerb::cSystem_oPb86mey_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KOyAKbne, HV_BINOP_SUBTRACT, 1, m, &cBinop_KOyAKbne_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Kc2Mgbkx, 2, m, &cDelay_Kc2Mgbkx_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Xuhrtue7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_oPb86mey_sendMessage);
}

void Heavy_ChaffVerb::cMsg_ehW6tAKD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_H8Gx4Ne0, 0, m, &cDelay_H8Gx4Ne0_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Kc2Mgbkx, 0, m, &cDelay_Kc2Mgbkx_sendMessage);
}

void Heavy_ChaffVerb::cMsg_a3nVOI5C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_OPvv6QhH, HV_BINOP_MAX, 1, m, &cBinop_OPvv6QhH_sendMessage);
}

void Heavy_ChaffVerb::cBinop_OPvv6QhH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sg5CTzNp, HV_BINOP_SUBTRACT, 1, m, &cBinop_sg5CTzNp_sendMessage);
}

void Heavy_ChaffVerb::cCast_RgIXwwCv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_H8Gx4Ne0, 0, m, &cDelay_H8Gx4Ne0_sendMessage);
}

void Heavy_ChaffVerb::cBinop_1TmAYPJ9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_H8Gx4Ne0, 2, m, &cDelay_H8Gx4Ne0_sendMessage);
}

void Heavy_ChaffVerb::cBinop_KOyAKbne_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_1TmAYPJ9_sendMessage);
}

void Heavy_ChaffVerb::cCast_IaETr6lG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1GhhzQiX, 0, m, &cVar_1GhhzQiX_sendMessage);
  cMsg_s43d9apf_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_3Z4GP1lw, 0, m, &cTabhead_3Z4GP1lw_sendMessage);
}

void Heavy_ChaffVerb::cVar_XToIk3cI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_7ggzn5Xa, 0, m, &cVar_7ggzn5Xa_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_870tR97r, 0, m, &cVar_870tR97r_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_36Hdjr4O, 0, m, &cVar_36Hdjr4O_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_VzFTSVBr, 0, m, &cVar_VzFTSVBr_sendMessage);
}

void Heavy_ChaffVerb::cVar_xH7yhFLM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.01f, 0, m, &cBinop_gdkvByGa_sendMessage);
}

void Heavy_ChaffVerb::cPack_nPkX560h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sLine_onMessage(_c, &Context(_c)->sLine_RHG7goVo, 0, m, NULL);
}

void Heavy_ChaffVerb::cVar_870tR97r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_v4aIcEEu, HV_BINOP_MULTIPLY, 0, m, &cBinop_v4aIcEEu_sendMessage);
}

void Heavy_ChaffVerb::cMsg_qE3KV6sc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_4CE8e95y_sendMessage);
}

void Heavy_ChaffVerb::cSystem_4CE8e95y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wtLtnUWo_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_v4aIcEEu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_1uNJKNyN_sendMessage);
}

void Heavy_ChaffVerb::cBinop_qm9mdiGV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_v4aIcEEu, HV_BINOP_MULTIPLY, 1, m, &cBinop_v4aIcEEu_sendMessage);
}

void Heavy_ChaffVerb::cMsg_wtLtnUWo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_qm9mdiGV_sendMessage);
}

void Heavy_ChaffVerb::cBinop_1uNJKNyN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_NxWgp1RW_sendMessage);
}

void Heavy_ChaffVerb::cBinop_NxWgp1RW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_eW8H9Y2U_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_RvKIPYNP, m);
}

void Heavy_ChaffVerb::cBinop_eW8H9Y2U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_ZQKv20K8, m);
}

void Heavy_ChaffVerb::cVar_36Hdjr4O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5bqI1w0a, HV_BINOP_MULTIPLY, 0, m, &cBinop_5bqI1w0a_sendMessage);
}

void Heavy_ChaffVerb::cMsg_IKFJzVKb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_13K29m74_sendMessage);
}

void Heavy_ChaffVerb::cSystem_13K29m74_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dDm1JzlE_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_5bqI1w0a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_rJPiPzuc_sendMessage);
}

void Heavy_ChaffVerb::cBinop_tJq7hsqs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5bqI1w0a, HV_BINOP_MULTIPLY, 1, m, &cBinop_5bqI1w0a_sendMessage);
}

void Heavy_ChaffVerb::cMsg_dDm1JzlE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_tJq7hsqs_sendMessage);
}

void Heavy_ChaffVerb::cBinop_rJPiPzuc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_zCwgdrpO_sendMessage);
}

void Heavy_ChaffVerb::cBinop_zCwgdrpO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_dEdQvdbt_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_BSaUrVwt, m);
}

void Heavy_ChaffVerb::cBinop_dEdQvdbt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_tHHlyqyZ, m);
}

void Heavy_ChaffVerb::cVar_VzFTSVBr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Joq4HPhn, HV_BINOP_MULTIPLY, 0, m, &cBinop_Joq4HPhn_sendMessage);
}

void Heavy_ChaffVerb::cMsg_ekrpEKbM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_r12xyFDw_sendMessage);
}

void Heavy_ChaffVerb::cSystem_r12xyFDw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_S4Wv85xM_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_Joq4HPhn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_UmyZoolH_sendMessage);
}

void Heavy_ChaffVerb::cBinop_COwCNYtw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Joq4HPhn, HV_BINOP_MULTIPLY, 1, m, &cBinop_Joq4HPhn_sendMessage);
}

void Heavy_ChaffVerb::cMsg_S4Wv85xM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_COwCNYtw_sendMessage);
}

void Heavy_ChaffVerb::cBinop_UmyZoolH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_4bv02oBp_sendMessage);
}

void Heavy_ChaffVerb::cBinop_4bv02oBp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_PixbKoF5_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_hTRYlyMl, m);
}

void Heavy_ChaffVerb::cBinop_PixbKoF5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_GJ8RYZCz, m);
}

void Heavy_ChaffVerb::cBinop_uB68DMSz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_JBiKGciB, 0, m, &cPack_JBiKGciB_sendMessage);
}

void Heavy_ChaffVerb::cMsg_UTNVBYnF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 3000.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_XToIk3cI, 0, m, &cVar_XToIk3cI_sendMessage);
}

void Heavy_ChaffVerb::cBinop_gdkvByGa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_nPkX560h, 0, m, &cPack_nPkX560h_sendMessage);
}

void Heavy_ChaffVerb::cBinop_G3XpwHNJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_wNA7kvlC, 0, m, &cPack_wNA7kvlC_sendMessage);
}

void Heavy_ChaffVerb::cSwitchcase_JHIKzsBm_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cMsg_vmHuSlu3_sendMessage(_c, 0, m);
      break;
    }
    case 0x7A5B032D: { // "stop"
      cMsg_vmHuSlu3_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OkqvprUU_sendMessage);
      break;
    }
  }
}

void Heavy_ChaffVerb::cDelay_FniIefJj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_FniIefJj, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_FniIefJj, 0, m, &cDelay_FniIefJj_sendMessage);
  cSwitchcase_djRIBQzX_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cCast_OkqvprUU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vmHuSlu3_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_FniIefJj, 0, m, &cDelay_FniIefJj_sendMessage);
  cSwitchcase_djRIBQzX_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cMsg_arFlRXFW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_EovWbvAP_sendMessage);
}

void Heavy_ChaffVerb::cSystem_EovWbvAP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_bCa55Dgs_sendMessage);
}

void Heavy_ChaffVerb::cVar_HEIBQLRE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_M7oZQur3, HV_BINOP_MULTIPLY, 0, m, &cBinop_M7oZQur3_sendMessage);
}

void Heavy_ChaffVerb::cMsg_vmHuSlu3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_FniIefJj, 0, m, &cDelay_FniIefJj_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Qrtx3T7c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_FniIefJj, 2, m, &cDelay_FniIefJj_sendMessage);
}

void Heavy_ChaffVerb::cBinop_bCa55Dgs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_M7oZQur3, HV_BINOP_MULTIPLY, 1, m, &cBinop_M7oZQur3_sendMessage);
}

void Heavy_ChaffVerb::cBinop_M7oZQur3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_Qrtx3T7c_sendMessage);
}

void Heavy_ChaffVerb::cVar_wv8dTcxM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MOD_UNIPOLAR, 628.0f, 0, m, &cBinop_0qR8tXAg_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 2.0f, 0, m, &cBinop_DRPxU21g_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_JoeXyhuP_sendMessage);
}

void Heavy_ChaffVerb::cVar_lCuSMW0x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_DSD6xFVT_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_9V1V6Fp4, 0, m, &cIf_9V1V6Fp4_sendMessage);
}

void Heavy_ChaffVerb::cUnop_KJHqhoHn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gTgtg2x7, HV_BINOP_MOD_UNIPOLAR, 1, m, &cBinop_gTgtg2x7_sendMessage);
}

void Heavy_ChaffVerb::cUnop_fxY7NK9u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gTgtg2x7, HV_BINOP_MOD_UNIPOLAR, 1, m, &cBinop_gTgtg2x7_sendMessage);
}

void Heavy_ChaffVerb::cIf_9V1V6Fp4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cUnop_onMessage(_c, HV_UNOP_CEIL, m, &cUnop_fxY7NK9u_sendMessage);
      break;
    }
    case 1: {
      cUnop_onMessage(_c, HV_UNOP_FLOOR, m, &cUnop_KJHqhoHn_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_DSD6xFVT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_9V1V6Fp4, 1, m, &cIf_9V1V6Fp4_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Wfs7qNLk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_6WZStDUG_sendMessage);
}

void Heavy_ChaffVerb::cSystem_6WZStDUG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_GUVMPm6m_sendMessage);
}

void Heavy_ChaffVerb::cDelay_PsJaucOg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_PsJaucOg, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_abrmloQ2, 0, m, &cDelay_abrmloQ2_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_PsJaucOg, 0, m, &cDelay_PsJaucOg_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_DcSXWpAy, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_abrmloQ2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_abrmloQ2, m);
  cMsg_XIB0Y6Ny_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_s3zLF1an_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_RgpLXTE8_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_38Dq8IKh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zd2Om2s5_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_qPv6SYuZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_q9Igubmu_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_PsJaucOg, 2, m, &cDelay_PsJaucOg_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_P2verSBN_sendMessage);
}

void Heavy_ChaffVerb::cMsg_zd2Om2s5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_qPv6SYuZ, 0, m, &hTable_qPv6SYuZ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_GUVMPm6m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 3000.0f, 0, m, &cBinop_38Dq8IKh_sendMessage);
}

void Heavy_ChaffVerb::cMsg_XIB0Y6Ny_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_qPv6SYuZ, 0, m, &hTable_qPv6SYuZ_sendMessage);
}

void Heavy_ChaffVerb::cCast_P2verSBN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_PsJaucOg, 0, m, &cDelay_PsJaucOg_sendMessage);
}

void Heavy_ChaffVerb::cMsg_q9Igubmu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_abrmloQ2, 2, m, &cDelay_abrmloQ2_sendMessage);
}

void Heavy_ChaffVerb::cMsg_RgpLXTE8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_DcSXWpAy, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_Qd19PyIl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Svo2ojuC, HV_BINOP_SUBTRACT, 0, m, &cBinop_Svo2ojuC_sendMessage);
}

void Heavy_ChaffVerb::cMsg_CtlClCf9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_OsDsDrq3_sendMessage);
}

void Heavy_ChaffVerb::cSystem_OsDsDrq3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_ipNUcMi8_sendMessage);
}

void Heavy_ChaffVerb::cVar_qLNXrpCm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IPTbz8Su_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_S0KJbk0R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_S0KJbk0R, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_djPkvxid, 0, m, &cDelay_djPkvxid_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_P8ehkYPp, 0, m, &sTabread_P8ehkYPp_sendMessage);
}

void Heavy_ChaffVerb::cDelay_djPkvxid_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_djPkvxid, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_P8ehkYPp, 0, m, &sTabread_P8ehkYPp_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_djPkvxid, 0, m, &cDelay_djPkvxid_sendMessage);
}

void Heavy_ChaffVerb::sTabread_P8ehkYPp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_3H9BCyXn, HV_BINOP_SUBTRACT, 0, m, &cBinop_3H9BCyXn_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_BhHweMHL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jCMoAAiZ, HV_BINOP_MAX, 0, m, &cBinop_jCMoAAiZ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_ipNUcMi8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BhHweMHL, HV_BINOP_MULTIPLY, 0, m, &cBinop_BhHweMHL_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Svo2ojuC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xPOW3ELI_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_P8ehkYPp, 0, m, &sTabread_P8ehkYPp_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IsmDKisa_sendMessage);
}

void Heavy_ChaffVerb::cSystem_7w49Bt1l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3H9BCyXn, HV_BINOP_SUBTRACT, 1, m, &cBinop_3H9BCyXn_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_djPkvxid, 2, m, &cDelay_djPkvxid_sendMessage);
}

void Heavy_ChaffVerb::cMsg_IPTbz8Su_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_7w49Bt1l_sendMessage);
}

void Heavy_ChaffVerb::cMsg_xPOW3ELI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_S0KJbk0R, 0, m, &cDelay_S0KJbk0R_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_djPkvxid, 0, m, &cDelay_djPkvxid_sendMessage);
}

void Heavy_ChaffVerb::cMsg_98XaneWX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_jCMoAAiZ, HV_BINOP_MAX, 1, m, &cBinop_jCMoAAiZ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_jCMoAAiZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Svo2ojuC, HV_BINOP_SUBTRACT, 1, m, &cBinop_Svo2ojuC_sendMessage);
}

void Heavy_ChaffVerb::cCast_IsmDKisa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_S0KJbk0R, 0, m, &cDelay_S0KJbk0R_sendMessage);
}

void Heavy_ChaffVerb::cBinop_6iD7Ntn5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_S0KJbk0R, 2, m, &cDelay_S0KJbk0R_sendMessage);
}

void Heavy_ChaffVerb::cBinop_3H9BCyXn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_6iD7Ntn5_sendMessage);
}

void Heavy_ChaffVerb::cCast_kV718FFK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_qLNXrpCm, 0, m, &cVar_qLNXrpCm_sendMessage);
  cMsg_CtlClCf9_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_Qd19PyIl, 0, m, &cTabhead_Qd19PyIl_sendMessage);
}

void Heavy_ChaffVerb::cSwitchcase_aGuwUUvD_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TG5jYFgP_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cCast_TG5jYFgP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XoLqzPA5_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cVar_zceXu0z1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1xSf6IJV, HV_BINOP_ADD, 0, m, &cBinop_1xSf6IJV_sendMessage);
}

void Heavy_ChaffVerb::cSwitchcase_ctLBx4Z6_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_H1TRBzEA_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cCast_H1TRBzEA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8KQ1A6ig_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cVar_wwjyLONC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bWaylPCT_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Cp4Ni6Wb_sendMessage);
}

void Heavy_ChaffVerb::cVar_1kM9Lyjj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_8eA3mzTq, 0, m, &cVar_8eA3mzTq_sendMessage);
}

void Heavy_ChaffVerb::cVar_8eA3mzTq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Q96JIfcf, HV_BINOP_ADD, 0, m, &cBinop_Q96JIfcf_sendMessage);
}

void Heavy_ChaffVerb::cVar_f5s8lD5r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BAQEzUDV, HV_BINOP_ADD, 0, m, &cBinop_BAQEzUDV_sendMessage);
}

void Heavy_ChaffVerb::cVar_EhZoxPnC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_tKpKF4cO_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_uKUdecVW, 0, m, &cIf_uKUdecVW_sendMessage);
}

void Heavy_ChaffVerb::cUnop_Q9KDbpTf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BAQEzUDV, HV_BINOP_ADD, 1, m, &cBinop_BAQEzUDV_sendMessage);
}

void Heavy_ChaffVerb::cUnop_We7pMSpN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BAQEzUDV, HV_BINOP_ADD, 1, m, &cBinop_BAQEzUDV_sendMessage);
}

void Heavy_ChaffVerb::cIf_uKUdecVW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cUnop_onMessage(_c, HV_UNOP_CEIL, m, &cUnop_We7pMSpN_sendMessage);
      break;
    }
    case 1: {
      cUnop_onMessage(_c, HV_UNOP_FLOOR, m, &cUnop_Q9KDbpTf_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_tKpKF4cO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_uKUdecVW, 1, m, &cIf_uKUdecVW_sendMessage);
}

void Heavy_ChaffVerb::cVar_fohi0EP4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_XhP4OtiB_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_a5DhQn8d, 0, m, &cIf_a5DhQn8d_sendMessage);
}

void Heavy_ChaffVerb::cUnop_jtPQX25A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Fph5q7I8_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cUnop_OkeDeAni_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Fph5q7I8_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cIf_a5DhQn8d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cUnop_onMessage(_c, HV_UNOP_CEIL, m, &cUnop_OkeDeAni_sendMessage);
      break;
    }
    case 1: {
      cUnop_onMessage(_c, HV_UNOP_FLOOR, m, &cUnop_jtPQX25A_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_XhP4OtiB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_a5DhQn8d, 1, m, &cIf_a5DhQn8d_sendMessage);
}

void Heavy_ChaffVerb::cSwitchcase_Fph5q7I8_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_h8wN5t0q, 0, m, &cSlice_h8wN5t0q_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_raZiFjZB, 0, m, &cSlice_raZiFjZB_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GMSOOr7Q_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_O1ZNdDbZ_sendMessage);
      break;
    }
  }
}

void Heavy_ChaffVerb::cSlice_h8wN5t0q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_qBHkjBEJ, 0, m, &cVar_qBHkjBEJ_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_qBHkjBEJ, 0, m, &cVar_qBHkjBEJ_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cSlice_raZiFjZB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_DU8eV5KV, HV_BINOP_NEQ, 1, m, &cBinop_DU8eV5KV_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_qBHkjBEJ, 1, m, &cVar_qBHkjBEJ_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_DU8eV5KV, HV_BINOP_NEQ, 1, m, &cBinop_DU8eV5KV_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_qBHkjBEJ, 1, m, &cVar_qBHkjBEJ_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cVar_qBHkjBEJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IHJi8dlS_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_We6lvphv_sendMessage);
}

void Heavy_ChaffVerb::cIf_E51ZYIw9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Fr7xs5Cl_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gyiZde7a_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cCast_gyiZde7a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_qBHkjBEJ, 0, m, &cVar_qBHkjBEJ_sendMessage);
}

void Heavy_ChaffVerb::cCast_Fr7xs5Cl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DU8eV5KV, HV_BINOP_NEQ, 1, m, &cBinop_DU8eV5KV_sendMessage);
}

void Heavy_ChaffVerb::cBinop_DU8eV5KV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_E51ZYIw9, 1, m, &cIf_E51ZYIw9_sendMessage);
}

void Heavy_ChaffVerb::cCast_GMSOOr7Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DU8eV5KV, HV_BINOP_NEQ, 0, m, &cBinop_DU8eV5KV_sendMessage);
}

void Heavy_ChaffVerb::cCast_O1ZNdDbZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_E51ZYIw9, 0, m, &cIf_E51ZYIw9_sendMessage);
}

void Heavy_ChaffVerb::cIf_dUeJW8P0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_1kM9Lyjj, 0, m, &cVar_1kM9Lyjj_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cIf_8Gs21bY2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cIf_onMessage(_c, &Context(_c)->cIf_dUeJW8P0, 0, m, &cIf_dUeJW8P0_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cIf_E6quI8sN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cIf_onMessage(_c, &Context(_c)->cIf_dUeJW8P0, 0, m, &cIf_dUeJW8P0_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cIf_EoviPapw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cIf_onMessage(_c, &Context(_c)->cIf_dUeJW8P0, 0, m, &cIf_dUeJW8P0_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cIf_PCRtKCLF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_wwjyLONC, 0, m, &cVar_wwjyLONC_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cCast_2nnMsq0K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_f5s8lD5r, 0, m, &cVar_f5s8lD5r_sendMessage);
}

void Heavy_ChaffVerb::cMsg_wBFSo0Gv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_8Gs21bY2, 1, m, &cIf_8Gs21bY2_sendMessage);
}

void Heavy_ChaffVerb::cMsg_yU9uGtZO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_EoviPapw, 1, m, &cIf_EoviPapw_sendMessage);
}

void Heavy_ChaffVerb::cMsg_sgNgPOyl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_8Gs21bY2, 1, m, &cIf_8Gs21bY2_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_E6quI8sN, 1, m, &cIf_E6quI8sN_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_EoviPapw, 1, m, &cIf_EoviPapw_sendMessage);
}

void Heavy_ChaffVerb::cBinop_4YUXW1Ft_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_zceXu0z1, 0, m, &cVar_zceXu0z1_sendMessage);
}

void Heavy_ChaffVerb::cBinop_pooyA0ml_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_4YUXW1Ft_sendMessage);
}

void Heavy_ChaffVerb::cMsg_8KQ1A6ig_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_wwjyLONC, 0, m, &cVar_wwjyLONC_sendMessage);
}

void Heavy_ChaffVerb::cBinop_gTgtg2x7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wFuVYI6y, HV_BINOP_MULTIPLY, 0, m, &cBinop_wFuVYI6y_sendMessage);
}

void Heavy_ChaffVerb::cBinop_JoeXyhuP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gTgtg2x7, HV_BINOP_MOD_UNIPOLAR, 0, m, &cBinop_gTgtg2x7_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Q8wZh0Bb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_E6quI8sN, 1, m, &cIf_E6quI8sN_sendMessage);
}

void Heavy_ChaffVerb::cBinop_BAQEzUDV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CTp6ftGN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HQ96rqae_sendMessage);
}

void Heavy_ChaffVerb::cBinop_wYd4cp7n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_kTHyhiYy, 0, m, &cVar_kTHyhiYy_sendMessage);
}

void Heavy_ChaffVerb::cCast_HQ96rqae_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1kM9Lyjj, 0, m, &cVar_1kM9Lyjj_sendMessage);
}

void Heavy_ChaffVerb::cCast_CTp6ftGN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wYd4cp7n, HV_BINOP_ADD, 1, m, &cBinop_wYd4cp7n_sendMessage);
}

void Heavy_ChaffVerb::cCast_IHJi8dlS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sgNgPOyl_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cCast_We6lvphv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_c15KAOQs_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cBinop_CGasukQS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_c6zEK3um, 0, m, &cVar_c6zEK3um_sendMessage);
}

void Heavy_ChaffVerb::cBinop_wFuVYI6y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_E6quI8sN, 0, m, &cIf_E6quI8sN_sendMessage);
}

void Heavy_ChaffVerb::cBinop_jcf94T5Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_EoviPapw, 0, m, &cIf_EoviPapw_sendMessage);
}

void Heavy_ChaffVerb::cBinop_PTQVqXil_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_rrlKy3jZ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 3.1415f, 0, m, &cBinop_jcf94T5Y_sendMessage);
}

void Heavy_ChaffVerb::cBinop_0qR8tXAg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 314.0f, 0, m, &cBinop_nOFPGKqD_sendMessage);
}

void Heavy_ChaffVerb::cBinop_nOFPGKqD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_PTQVqXil_sendMessage);
}

void Heavy_ChaffVerb::cBinop_DRPxU21g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_wv8dTcxM, 1, m, &cVar_wv8dTcxM_sendMessage);
}

void Heavy_ChaffVerb::cBinop_uEthG7RL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_nknlzmzF, 0, m, &cVar_nknlzmzF_sendMessage);
}

void Heavy_ChaffVerb::cBinop_WEkHzUpG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_HEIBQLRE, 0, m, &cVar_HEIBQLRE_sendMessage);
}

void Heavy_ChaffVerb::cMsg_XoLqzPA5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_1kM9Lyjj, 0, m, &cVar_1kM9Lyjj_sendMessage);
}

void Heavy_ChaffVerb::cBinop_1xSf6IJV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_imJ3hHTn, HV_BINOP_MULTIPLY, 0, m, &cBinop_imJ3hHTn_sendMessage);
}

void Heavy_ChaffVerb::cBinop_imJ3hHTn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_PCRtKCLF, 0, m, &cIf_PCRtKCLF_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Ebl1qs5H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wYd4cp7n, HV_BINOP_ADD, 0, m, &cBinop_wYd4cp7n_sendMessage);
}

void Heavy_ChaffVerb::cCast_Cp4Ni6Wb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1kM9Lyjj, 0, m, &cVar_1kM9Lyjj_sendMessage);
}

void Heavy_ChaffVerb::cCast_bWaylPCT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ebl1qs5H, HV_BINOP_ADD, 1, m, &cBinop_Ebl1qs5H_sendMessage);
}

void Heavy_ChaffVerb::cCast_LnXw77U9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dUeJW8P0, 1, m, &cIf_dUeJW8P0_sendMessage);
}

void Heavy_ChaffVerb::cCast_7X5Coj8S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_aGuwUUvD_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cCast_zvljxCMo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_imJ3hHTn, HV_BINOP_MULTIPLY, 1, m, &cBinop_imJ3hHTn_sendMessage);
}

void Heavy_ChaffVerb::cCast_BCIeFYZI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_zceXu0z1, 0, m, &cVar_zceXu0z1_sendMessage);
}

void Heavy_ChaffVerb::cCast_1GeZCDsV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_PCRtKCLF, 1, m, &cIf_PCRtKCLF_sendMessage);
}

void Heavy_ChaffVerb::cCast_r784Q2R5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_ctLBx4Z6_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cCast_txVUfyjq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1xSf6IJV, HV_BINOP_ADD, 1, m, &cBinop_1xSf6IJV_sendMessage);
}

void Heavy_ChaffVerb::cCast_U5HEgj1P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_zceXu0z1, 0, m, &cVar_zceXu0z1_sendMessage);
}

void Heavy_ChaffVerb::cBinop_XfPGrSpB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ebl1qs5H, HV_BINOP_ADD, 0, m, &cBinop_Ebl1qs5H_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Q96JIfcf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XfPGrSpB, HV_BINOP_MULTIPLY, 0, m, &cBinop_XfPGrSpB_sendMessage);
}

void Heavy_ChaffVerb::cCast_E3yvupMM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XfPGrSpB, HV_BINOP_MULTIPLY, 1, m, &cBinop_XfPGrSpB_sendMessage);
}

void Heavy_ChaffVerb::cCast_BugljAKE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1kM9Lyjj, 0, m, &cVar_1kM9Lyjj_sendMessage);
}

void Heavy_ChaffVerb::cCast_RmXxLj9r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1kM9Lyjj, 0, m, &cVar_1kM9Lyjj_sendMessage);
}

void Heavy_ChaffVerb::cCast_qcMciCFH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Q96JIfcf, HV_BINOP_ADD, 1, m, &cBinop_Q96JIfcf_sendMessage);
}

void Heavy_ChaffVerb::cMsg_dxnOvtov_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IHJi8dlS_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_We6lvphv_sendMessage);
}

void Heavy_ChaffVerb::cReceive_WHp89IcV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7ThxcDek_sendMessage(_c, 0, m);
  cMsg_pcGEEDB2_sendMessage(_c, 0, m);
  cMsg_N6jr4Ckb_sendMessage(_c, 0, m);
  cMsg_MBwZye4N_sendMessage(_c, 0, m);
  cMsg_9WYVuL60_sendMessage(_c, 0, m);
  cMsg_ZN9jokWa_sendMessage(_c, 0, m);
  cMsg_Y46mOHFG_sendMessage(_c, 0, m);
  cMsg_6kPqJ1hx_sendMessage(_c, 0, m);
  cMsg_sKm1mgSw_sendMessage(_c, 0, m);
  cMsg_Gl43MpP2_sendMessage(_c, 0, m);
  cMsg_ArNEA6sz_sendMessage(_c, 0, m);
  cMsg_pZycvGpy_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_7ggzn5Xa, 0, m, &cVar_7ggzn5Xa_sendMessage);
  cMsg_qE3KV6sc_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_870tR97r, 0, m, &cVar_870tR97r_sendMessage);
  cMsg_IKFJzVKb_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_36Hdjr4O, 0, m, &cVar_36Hdjr4O_sendMessage);
  cMsg_ekrpEKbM_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_VzFTSVBr, 0, m, &cVar_VzFTSVBr_sendMessage);
  cMsg_F8HtLmXE_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_vMM3bEiQ, 0, m, &cVar_vMM3bEiQ_sendMessage);
  cMsg_yLnEQeGy_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_nknlzmzF, 0, m, &cVar_nknlzmzF_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_GeRuZH7Z, 0, m, &cVar_GeRuZH7Z_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_c6zEK3um, 0, m, &cVar_c6zEK3um_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_mwrwjSDQ, 0, m, &cVar_mwrwjSDQ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_rEr8UQZ4, 0, m, &cVar_rEr8UQZ4_sendMessage);
  cMsg_arFlRXFW_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_HEIBQLRE, 0, m, &cVar_HEIBQLRE_sendMessage);
  cMsg_Wfs7qNLk_sendMessage(_c, 0, m);
  cSwitchcase_aQukJHnF_onMessage(_c, NULL, 0, m, NULL);
  cMsg_XoLqzPA5_sendMessage(_c, 0, m);
  cMsg_dxnOvtov_sendMessage(_c, 0, m);
  cMsg_8KQ1A6ig_sendMessage(_c, 0, m);
  cSwitchcase_JHIKzsBm_onMessage(_c, NULL, 0, m, NULL);
  cVar_onMessage(_c, &Context(_c)->cVar_gVigWLva, 0, m, &cVar_gVigWLva_sendMessage);
  cMsg_jNee8IXR_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_gN1ufwuj, 0, m, &cVar_gN1ufwuj_sendMessage);
  cMsg_QTZvosFJ_sendMessage(_c, 0, m);
  cMsg_kdT6nrmn_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_P7D9lUQL, 0, m, &cVar_P7D9lUQL_sendMessage);
  cMsg_BbvRIzj2_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_7rF397Ln, 0, m, &cTabhead_7rF397Ln_sendMessage);
  cMsg_mDQE0neO_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_duAmrU2D, 0, m, &cVar_duAmrU2D_sendMessage);
  cMsg_N4z46cdl_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_VA4Dpeln, 0, m, &cTabhead_VA4Dpeln_sendMessage);
  cMsg_309yVvD4_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_UQx5Ua7V, 0, m, &cVar_UQx5Ua7V_sendMessage);
  cMsg_Jc3YVD6l_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_XqHlMAIZ, 0, m, &cTabhead_XqHlMAIZ_sendMessage);
  cMsg_3QmcAzeL_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_8J0IaKxO, 0, m, &cVar_8J0IaKxO_sendMessage);
  cMsg_4BG8WR8j_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_UAq06X24, 0, m, &cTabhead_UAq06X24_sendMessage);
  cMsg_TPV2IYLr_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_jJcbCOKM, 0, m, &cVar_jJcbCOKM_sendMessage);
  cMsg_P1dpeHgH_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_x2nIKaC8, 0, m, &cTabhead_x2nIKaC8_sendMessage);
  cMsg_wGVAWwuB_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_Mf7QKgUx, 0, m, &cVar_Mf7QKgUx_sendMessage);
  cMsg_wHRToKRL_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_6Vy8nZVe, 0, m, &cTabhead_6Vy8nZVe_sendMessage);
  cMsg_8PaZS3po_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_bgjx0mgk, 0, m, &cVar_bgjx0mgk_sendMessage);
  cMsg_CB0huZq9_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_zyHrbWra, 0, m, &cTabhead_zyHrbWra_sendMessage);
  cMsg_fcKyUGis_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_zzQBv86M, 0, m, &cVar_zzQBv86M_sendMessage);
  cMsg_Eb64wrwn_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_20BNRcIp, 0, m, &cTabhead_20BNRcIp_sendMessage);
  cMsg_A96hIF3Z_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_ESqy9KLJ, 0, m, &cVar_ESqy9KLJ_sendMessage);
  cMsg_YpElZbo7_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_ojFAOURY, 0, m, &cTabhead_ojFAOURY_sendMessage);
  cMsg_a3nVOI5C_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_1GhhzQiX, 0, m, &cVar_1GhhzQiX_sendMessage);
  cMsg_s43d9apf_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_3Z4GP1lw, 0, m, &cTabhead_3Z4GP1lw_sendMessage);
  cMsg_98XaneWX_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_qLNXrpCm, 0, m, &cVar_qLNXrpCm_sendMessage);
  cMsg_CtlClCf9_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_Qd19PyIl, 0, m, &cTabhead_Qd19PyIl_sendMessage);
}

void Heavy_ChaffVerb::cReceive_LagiHFgr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 157.0f, 0, m, &cBinop_uEthG7RL_sendMessage);
}

void Heavy_ChaffVerb::cReceive_7uzdluK5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_fohi0EP4, 0, m, &cVar_fohi0EP4_sendMessage);
}

void Heavy_ChaffVerb::cReceive_Pj7QEql7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_lCuSMW0x, 0, m, &cVar_lCuSMW0x_sendMessage);
}

void Heavy_ChaffVerb::cReceive_PO6ifWxZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wFuVYI6y, HV_BINOP_MULTIPLY, 1, m, &cBinop_wFuVYI6y_sendMessage);
}

void Heavy_ChaffVerb::cReceive_9abq3WiE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qcMciCFH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RmXxLj9r_sendMessage);
}

void Heavy_ChaffVerb::cReceive_9itnJKNa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_E3yvupMM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BugljAKE_sendMessage);
}

void Heavy_ChaffVerb::cReceive_w3eOFv0L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_f5s8lD5r, 0, m, &cVar_f5s8lD5r_sendMessage);
}

void Heavy_ChaffVerb::cReceive_j6ciMmg6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2nnMsq0K_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_EhZoxPnC, 0, m, &cVar_EhZoxPnC_sendMessage);
}

void Heavy_ChaffVerb::cReceive_CLixaqgH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 157.0f, 0, m, &cBinop_WEkHzUpG_sendMessage);
}

void Heavy_ChaffVerb::cReceive_z6tYpPbN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_txVUfyjq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_U5HEgj1P_sendMessage);
}

void Heavy_ChaffVerb::cReceive_c7kesexW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zvljxCMo_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BCIeFYZI_sendMessage);
}

void Heavy_ChaffVerb::cReceive_sC0lFmd6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1GeZCDsV_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_r784Q2R5_sendMessage);
}

void Heavy_ChaffVerb::cReceive_KKh5G0Rb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_8xp9QnxE, m);
}

void Heavy_ChaffVerb::cReceive_Md9Z4CsW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_hVfbTIFr, m);
}

void Heavy_ChaffVerb::cReceive_j1eSrFq1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_GeRuZH7Z, 0, m, &cVar_GeRuZH7Z_sendMessage);
}

void Heavy_ChaffVerb::cReceive_A1LPCwC8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 100.0f, 0, m, &cBinop_CGasukQS_sendMessage);
}

void Heavy_ChaffVerb::cReceive_FZeOcAZs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_vRXYPTzD, 0, m, &cVar_vRXYPTzD_sendMessage);
}

void Heavy_ChaffVerb::cReceive_kDKz0ruv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Ioq1yAOj, 0, m, &cVar_Ioq1yAOj_sendMessage);
}

void Heavy_ChaffVerb::cReceive_gQXAcfx6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_vMM3bEiQ, 0, m, &cVar_vMM3bEiQ_sendMessage);
}

void Heavy_ChaffVerb::cReceive_jHrKk7A3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_cEE2hDdx, m);
}

void Heavy_ChaffVerb::cReceive_DHhSlRP0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_zPWMMrq9, m);
}

void Heavy_ChaffVerb::cReceive_YCcSeHsB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BhHweMHL, HV_BINOP_MULTIPLY, 1, m, &cBinop_BhHweMHL_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kV718FFK_sendMessage);
}

void Heavy_ChaffVerb::cReceive_wcthEm55_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LnXw77U9_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7X5Coj8S_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_ChaffVerb::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8, Bf9, Bf10, Bf11, Bf12, Bf13, Bf14;
  hv_bufferi_t Bi0, Bi1;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_phasor_k_f(&sPhasor_jqFAl0mu, VOf(Bf0));
    __hv_var_k_f(VOf(Bf1), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_floor_f(VIf(Bf2), VOf(Bf1));
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_abs_f(VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f);
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f);
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_mul_f(VIf(Bf2), VIf(Bf2), VOf(Bf1));
    __hv_mul_f(VIf(Bf2), VIf(Bf1), VOf(Bf3));
    __hv_mul_f(VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf4), 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f);
    __hv_var_k_f(VOf(Bf5), 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f);
    __hv_mul_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_sub_f(VIf(Bf2), VIf(Bf5), VOf(Bf5));
    __hv_fma_f(VIf(Bf1), VIf(Bf4), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_adXc1aZq, VOf(Bf4));
    __hv_line_f(&sLine_w4AE0Pc3, VOf(Bf1));
    __hv_fma_f(VIf(Bf0), VIf(Bf4), VIf(Bf1), VOf(Bf2));
    __hv_tabhead_f(&sTabhead_llE3uGZ9, VOf(Bf3));
    __hv_var_k_f_r(VOf(Bf6), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf3), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_7exNcQqJ, VOf(Bf3));
    __hv_mul_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_SXxXcnZP, VOf(Bf2));
    __hv_min_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_zero_f(VOf(Bf3));
    __hv_max_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_sub_f(VIf(Bf6), VIf(Bf3), VOf(Bf3));
    __hv_floor_f(VIf(Bf3), VOf(Bf6));
    __hv_varread_f(&sVarf_kyYyuJYL, VOf(Bf2));
    __hv_zero_f(VOf(Bf7));
    __hv_lt_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_and_f(VIf(Bf2), VIf(Bf7), VOf(Bf7));
    __hv_add_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_cast_fi(VIf(Bf7), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_BxOq9RFd, VIi(Bi1), VOf(Bf7));
    __hv_tabread_if(&sTabread_1icfGVw7, VIi(Bi0), VOf(Bf2));
    __hv_sub_f(VIf(Bf7), VIf(Bf2), VOf(Bf7));
    __hv_sub_f(VIf(Bf3), VIf(Bf6), VOf(Bf6));
    __hv_fma_f(VIf(Bf7), VIf(Bf6), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf6), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_add_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_floor_f(VIf(Bf6), VOf(Bf0));
    __hv_sub_f(VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf6), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf7), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_mul_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_floor_f(VIf(Bf7), VOf(Bf6));
    __hv_sub_f(VIf(Bf7), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf7), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_abs_f(VIf(Bf7), VOf(Bf7));
    __hv_var_k_f(VOf(Bf6), 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f);
    __hv_sub_f(VIf(Bf7), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf7), 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f);
    __hv_mul_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_mul_f(VIf(Bf7), VIf(Bf7), VOf(Bf6));
    __hv_mul_f(VIf(Bf7), VIf(Bf6), VOf(Bf3));
    __hv_mul_f(VIf(Bf3), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf8), 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f);
    __hv_var_k_f(VOf(Bf9), 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f);
    __hv_mul_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_sub_f(VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf6), VIf(Bf8), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf0), VIf(Bf4), VIf(Bf1), VOf(Bf1));
    __hv_tabhead_f(&sTabhead_eSiD4ph9, VOf(Bf4));
    __hv_var_k_f_r(VOf(Bf0), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf4), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_7HLaK9Ca, VOf(Bf4));
    __hv_mul_f(VIf(Bf1), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_ibCuJfoF, VOf(Bf1));
    __hv_min_f(VIf(Bf4), VIf(Bf1), VOf(Bf1));
    __hv_zero_f(VOf(Bf4));
    __hv_max_f(VIf(Bf1), VIf(Bf4), VOf(Bf4));
    __hv_sub_f(VIf(Bf0), VIf(Bf4), VOf(Bf4));
    __hv_floor_f(VIf(Bf4), VOf(Bf0));
    __hv_varread_f(&sVarf_wyF0t4Nh, VOf(Bf1));
    __hv_zero_f(VOf(Bf8));
    __hv_lt_f(VIf(Bf0), VIf(Bf8), VOf(Bf8));
    __hv_and_f(VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_add_f(VIf(Bf0), VIf(Bf8), VOf(Bf8));
    __hv_cast_fi(VIf(Bf8), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_VgKBW2M2, VIi(Bi1), VOf(Bf8));
    __hv_tabread_if(&sTabread_cBTnkZnp, VIi(Bi0), VOf(Bf1));
    __hv_sub_f(VIf(Bf8), VIf(Bf1), VOf(Bf8));
    __hv_sub_f(VIf(Bf4), VIf(Bf0), VOf(Bf0));
    __hv_fma_f(VIf(Bf8), VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_mul_f(VIf(Bf9), VIf(Bf1), VOf(Bf1));
    __hv_fma_f(VIf(Bf5), VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_tabwrite_f(&sTabwrite_tSJrGowR, VIf(I0));
    __hv_varread_f(&sVarf_3z5ORaK8, VOf(Bf2));
    __hv_rpole_f(&sRPole_9rrRq1bE, VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_WutqWsYf, VIf(Bf2), VOf(Bf5));
    __hv_mul_f(VIf(Bf5), VIf(Bf1), VOf(Bf1));
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_DtIkXdBW, VOf(Bf2));
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_cEE2hDdx, VOf(Bf1));
    __hv_tabread_f(&sTabread_P8ehkYPp, VOf(Bf5));
    __hv_varread_f(&sVarf_zPWMMrq9, VOf(Bf9));
    __hv_mul_f(VIf(Bf5), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf2), VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_tabwrite_f(&sTabwrite_DcSXWpAy, VIf(Bf9));
    __hv_varread_f(&sVarf_hVfbTIFr, VOf(Bf9));
    __hv_fma_f(VIf(I0), VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_tabread_f(&sTabread_32892OHy, VOf(Bf9));
    __hv_varread_f(&sVarf_LkrWIftb, VOf(Bf1));
    __hv_mul_f(VIf(Bf9), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_CERnyAlN, VOf(Bf2));
    __hv_rpole_f(&sRPole_SINHaRIo, VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_sub_f(VIf(Bf2), VIf(Bf9), VOf(Bf2));
    __hv_line_f(&sLine_RHG7goVo, VOf(Bf1));
    __hv_fma_f(VIf(Bf2), VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_ynbCPTOR, VOf(Bf2));
    __hv_tabread_f(&sTabread_XTMScFCN, VOf(Bf0));
    __hv_add_f(VIf(Bf5), VIf(Bf0), VOf(Bf8));
    __hv_tabread_f(&sTabread_M0VW0xTw, VOf(Bf4));
    __hv_add_f(VIf(Bf8), VIf(Bf4), VOf(Bf6));
    __hv_tabread_f(&sTabread_eJqQW8jk, VOf(Bf7));
    __hv_add_f(VIf(Bf6), VIf(Bf7), VOf(Bf3));
    __hv_tabread_f(&sTabread_roh7vvPE, VOf(Bf10));
    __hv_add_f(VIf(Bf3), VIf(Bf10), VOf(Bf11));
    __hv_tabread_f(&sTabread_myNO78PS, VOf(Bf12));
    __hv_add_f(VIf(Bf11), VIf(Bf12), VOf(Bf13));
    __hv_tabread_f(&sTabread_UI1hGaCm, VOf(Bf14));
    __hv_tabwrite_f(&sTabwrite_SBUXmKRO, VIf(Bf5));
    __hv_sub_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_tabwrite_f(&sTabwrite_WbBLYnnu, VIf(Bf0));
    __hv_sub_f(VIf(Bf8), VIf(Bf4), VOf(Bf4));
    __hv_tabwrite_f(&sTabwrite_GWSzT4Ha, VIf(Bf4));
    __hv_sub_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_tabwrite_f(&sTabwrite_F6KBU0Qs, VIf(Bf7));
    __hv_sub_f(VIf(Bf11), VIf(Bf12), VOf(Bf12));
    __hv_tabwrite_f(&sTabwrite_OR6AOtRm, VIf(Bf12));
    __hv_sub_f(VIf(Bf3), VIf(Bf10), VOf(Bf10));
    __hv_tabwrite_f(&sTabwrite_jDiXJTXV, VIf(Bf10));
    __hv_fma_f(VIf(Bf9), VIf(Bf2), VIf(Bf13), VOf(Bf13));
    __hv_tabread_f(&sTabread_th3G4Otl, VOf(Bf9));
    __hv_varread_f(&sVarf_RvKIPYNP, VOf(Bf10));
    __hv_mul_f(VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_ZQKv20K8, VOf(Bf3));
    __hv_rpole_f(&sRPole_szYy3G4Y, VIf(Bf10), VIf(Bf3), VOf(Bf3));
    __hv_sub_f(VIf(Bf3), VIf(Bf9), VOf(Bf3));
    __hv_fma_f(VIf(Bf3), VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf9), VIf(Bf2), VIf(Bf14), VOf(Bf14));
    __hv_add_f(VIf(Bf13), VIf(Bf14), VOf(Bf9));
    __hv_tabread_f(&sTabread_AE4mA9Hx, VOf(Bf3));
    __hv_varread_f(&sVarf_BSaUrVwt, VOf(Bf10));
    __hv_mul_f(VIf(Bf3), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_tHHlyqyZ, VOf(Bf12));
    __hv_rpole_f(&sRPole_YJJdJTRL, VIf(Bf10), VIf(Bf12), VOf(Bf12));
    __hv_sub_f(VIf(Bf12), VIf(Bf3), VOf(Bf12));
    __hv_fma_f(VIf(Bf12), VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_mul_f(VIf(Bf3), VIf(Bf2), VOf(Bf3));
    __hv_tabread_f(&sTabread_X6xTsZnq, VOf(Bf12));
    __hv_varread_f(&sVarf_hTRYlyMl, VOf(Bf10));
    __hv_mul_f(VIf(Bf12), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_GJ8RYZCz, VOf(Bf11));
    __hv_rpole_f(&sRPole_yQ0RDj9k, VIf(Bf10), VIf(Bf11), VOf(Bf11));
    __hv_sub_f(VIf(Bf11), VIf(Bf12), VOf(Bf11));
    __hv_fma_f(VIf(Bf11), VIf(Bf1), VIf(Bf12), VOf(Bf12));
    __hv_mul_f(VIf(Bf12), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf3), VIf(Bf2), VOf(Bf12));
    __hv_add_f(VIf(Bf9), VIf(Bf12), VOf(Bf1));
    __hv_tabwrite_f(&sTabwrite_MMvhf21d, VIf(Bf1));
    __hv_sub_f(VIf(Bf13), VIf(Bf14), VOf(Bf1));
    __hv_sub_f(VIf(Bf3), VIf(Bf2), VOf(Bf11));
    __hv_add_f(VIf(Bf1), VIf(Bf11), VOf(Bf10));
    __hv_tabwrite_f(&sTabwrite_YERfVzFy, VIf(Bf10));
    __hv_sub_f(VIf(Bf9), VIf(Bf12), VOf(Bf12));
    __hv_tabwrite_f(&sTabwrite_O51OxZpp, VIf(Bf12));
    __hv_sub_f(VIf(Bf1), VIf(Bf11), VOf(Bf11));
    __hv_tabwrite_f(&sTabwrite_Lw4JCPC8, VIf(Bf11));
    __hv_line_f(&sLine_J29RWejQ, VOf(Bf11));
    __hv_mul_f(VIf(Bf13), VIf(Bf11), VOf(Bf13));
    __hv_mul_f(VIf(Bf14), VIf(Bf11), VOf(Bf14));
    __hv_mul_f(VIf(Bf3), VIf(Bf11), VOf(Bf3));
    __hv_mul_f(VIf(Bf2), VIf(Bf11), VOf(Bf11));
    __hv_add_f(VIf(Bf14), VIf(Bf3), VOf(Bf3));
    __hv_add_f(VIf(Bf3), VIf(Bf11), VOf(Bf11));
    __hv_varread_f(&sVarf_8xp9QnxE, VOf(Bf3));
    __hv_mul_f(VIf(I0), VIf(Bf3), VOf(Bf3));
    __hv_add_f(VIf(Bf11), VIf(Bf3), VOf(Bf11));
    __hv_add_f(VIf(Bf11), VIf(O1), VOf(O1));
    __hv_add_f(VIf(Bf13), VIf(Bf3), VOf(Bf3));
    __hv_add_f(VIf(Bf3), VIf(O0), VOf(O0));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_ChaffVerb::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 1 channel(s)
  float **const bIn = &inputBuffers;

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_ChaffVerb::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 1 channel(s), uninterleave
  float *const bIn = inputBuffers;

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
